*! version 0.3 10oct2020
program distcomp, rclass sortpreserve byable(recall)
  version 11
  syntax varname(numeric default=none) [if] [in] , BY(varname) [Alpha(real 0.10) Pvalue noplot GROPTLINE0(string asis) GROPTLINE1(string asis) GROPTTWOWAY(string asis) GROPTREJ(string asis) SAVING(string)]
  *syntax varname(numeric default=none) [if] [in] , BY(varname) [Alpha(real 0.10) Pvalue noplot]
  if (`"`groptrej'"'=="") {
    local groptrej lwidth(thick) lcolor(black) lpattern(solid)
  }
  * Basic setup and check for problems before calling mata function
  if (`alpha'!=0.10 & `alpha'!=0.05 & `alpha'!=0.01) {
    display as error "Need to choose alpha equal to 0.10 or 0.05 or 0.01 (or else use the R version)"
    exit
  }
  marksample touse
  qui replace `touse'=0 if missing(`by')
  qui replace `touse'=0 if missing(`varlist')
  qui count if `touse'
  if !r(N) { //taken from ksmirnov.ado
    error 2000
  }
  qui tab `by' if `touse' , matrow(vals)
  if r(r) != 2 {
    di as error "`by' takes on " r(r) " values, not 2"
    exit 450
  }
  scalar pflag = ("`pvalue'"=="pvalue") // compute global p-value?

  * Main subroutine call
  mata: distcompmain("`varlist'", "`by'", `alpha', "`touse'", GoldmanKaplan2sLookup, "vals", "pflag")

  * Store r() values
  return scalar alpha = `alpha'
  return scalar alpha_sim = distcompalphasim // simulated maximum alpha (if applicable)
  if (pflag) { // global/GOF p-value
    if (distcompglobalpvalue>0) {
      return scalar p_gof = distcompglobalpvalue
    }
    else {
      return scalar p_gof = 1/1e4
    }
  }
  return scalar rej_gof01 = (distcompglobalrej1>0) //  1% level: 1 (reject global H0:F0()=F1()) or 0 (don't)
  return scalar rej_gof05 = (distcompglobalrej5>0) //  5% level: 1 (reject global H0:F0()=F1()) or 0 (don't)
  return scalar rej_gof10 = (distcompglobalrej10>0) // 10% level: 1 (reject global H0:F0()=F1()) or 0 (don't)
  matrix colnames distcompN = Ntotal Ngroup1 Ngroup2
  return matrix N = distcompN // number of observations
  matrix colnames distcomprejranges = from to

  * Display some results
  * Global/GOF results
  di as text "Comparing distribution of `varlist' when `by'=" vals[2,1] " vs. `by'=" vals[1,1]
  di as text " "
  di as text "Global test of equality of two CDFs:"
  if (pflag) {
    if (distcompglobalpvalue>0) {
      di as result "    Simulated p-value = " distcompglobalpvalue 
    }
    else {
      di as result "    Simulated p-value < " 1/1e4
    }
  }

  * Global/GOF test results for alpha=1%,5%,10%
  foreach a in 10 5 1 {
    local rejtxt "do not reject"
    if (distcompglobalrej`a'>0) {
      local rejtxt "reject"
    }
    if (distcompglobalrej`a'==1) {
      local rejtxt "reject (<)"
    }
    else if (distcompglobalrej`a'==2) {
      local rejtxt "reject (>)"
    }
    else if (distcompglobalrej`a'==3) {
      local rejtxt "reject (< and >)"
    }
    if (`a'<10) {
      di as result "    At a  `a'% level: `rejtxt'"
    }
    else {
      di as result "    At a `a'% level: `rejtxt'"
    }
  }

  * Rejected ranges (MTP results)
  local levperc `=100*`alpha''
  if (distcompglobalrej`levperc'>0) {
    di as text " "
    di as text "With strong control of FWER at a `levperc'% level,"
    di as text "CDF equality is rejected at all points in the following"
    di as text "ranges of `varlist' (in favor of first CDF < or >):"
    // matlist distcomprejranges , colorcoleq(res) lines(none) names(columns)
    matlist distcomprejranges , colorcoleq(res) lines(none) twidth(5)
  }
  tempname rejrows
  local `rejrows' = rowsof(distcomprejranges)

  * Plot ECDFs and indicate rejected ranges graphically
  if ("`plot'"!="noplot") {
    tempvar F0 F1
    cumul `varlist' if `touse' & `by'==vals[2,1] , g(`F1')
    cumul `varlist' if `touse' & `by'==vals[1,1] , g(`F0')
    sort `touse' `by' `varlist' `F0' `F1'
    * OVER 32-CHARACTER LIMIT =( local gname "distcomp_`varlist'_by_`by'_alpha`levperc'_`=_byindex()'"
    local gname "distcomp_`=_byindex()'"
    capture graph drop "`gname'"
    graph twoway (line `F1' `varlist' if `touse' & `by'==vals[2,1] , connect(stairstep) `groptline1') ///
                 (line `F0' `varlist' if `touse' & `by'==vals[1,1] , connect(stairstep) `groptline0') ///
          , name("`gname'") legend(lab(1 "`by'=`=vals[2,1]'") lab(2 "`by'=`=vals[1,1]'")) `gropttwoway'
    if (distcompglobalrej`levperc'>0) {
      forvalues r = 1/``rejrows'' {
        graph addplot function y=0 , range(`=distcomprejranges[`r',1]' `=distcomprejranges[`r',2]') `groptrej' , legend(order(1 "`by'=`=vals[2,1]'" 2 "`by'=`=vals[1,1]'" 3 "rejected ranges (`levperc'% FWER)"))
        *see https://www.stata.com/statalist/archive/2006-05/msg00249.html
      }
    }
    if ("`saving'"!="") {
      graph save `gname' `saving'
    }
  }
  return matrix rej_ranges = distcomprejranges // rows=ranges with level-alpha stat. sig. difference
end
*
*
*
mata:
void distcompmain(string scalar yname, string scalar catname, real scalar alpha, string scalar touse, real matrix LOOKUP, string scalar vals, string scalar pvalueflagname) {
  real scalar i, cnt, a, p, n0, n1 // counters, sample sizes
  transmorphic scalar val0, val1 // category variable values
  real colvector y // from dataset
  transmorphic colvector cat // from dataset
  real colvector y0, y1, y0uniq, y1uniq // y when cat=val0 and y when cat=val1
  real colvector aret
  real matrix CI0raw, CI1raw, CI0, CI1, rejranges, tmpmat0, tmpmat1
  string matrix rowstr
  tmp = st_matrix(vals)
  val0 = tmp[1]
  val1 = tmp[2]
  pvalueflag = st_numscalar(pvalueflagname)
  st_view(y, ., yname, touse)
  st_view(cat, ., catname, touse)
  y0 = J(colsum(cat:==val0),1,.)
  y1 = J(colsum(cat:==val1),1,.)
  n0 = 0
  n1 = 0
  for (i=1; i<=length(y); i++) {
    if (cat[i]==val0) {
      n0++
      y0[n0] = y[i]
    }
    else if (cat[i]==val1) {
      n1++
      y1[n1] = y[i]
    }
    else {
      cat[i]
       _error(sprintf("group variable %s takes a third value; should only have two",catname))
    }
  }
  if (n0/n1<0.05 | n1/n0<0.05) {
    printf("{err}warning: one group's size is <5%% of the other group; performance has not been studied thoroughly in such cases.\n")
  }
  st_matrix("distcompN",(n0+n1,n0,n1))
  //sort y values within group
  y0 = sort(y0,1)
  y1 = sort(y1,1)
  for (i=1;i<=3;i++) {
    a = i^2 + (i>1) // a=1,5,10
    // get alpha.tilde (and alpha.sim)
    aret = distcompalpha(n0, n1, a, LOOKUP)
    // compute CIs for y0 and y1
    CI0 = distcompCI(n0,aret[1])
    CI1 = distcompCI(n1,aret[1])
    // If duplicate values in y0 or y1, remove them,
    //    and adjust CIs accordingly
    tmpmat0 = distcompuniqCI(y0,CI0)
    tmpmat1 = distcompuniqCI(y1,CI1)
    // compute ranges of rejection (and 3rd column = which direction)
    rejranges = distcomprejranges(tmpmat0[.,1],tmpmat1[.,1],tmpmat0[.,2..3],tmpmat1[.,2..3])

    // store return values
    // st_numscalar(sprintf("distcompglobalrej%f",a), rows(rejranges)>0)
    st_numscalar(sprintf("distcompglobalrej%f",a), anyof(rejranges[.,3],1)+2*anyof(rejranges[.,3],0))
    if (abs(100*alpha-a)<0.000001) { // store rej ranges only for desired alpha level
      st_numscalar("distcompalphasim",aret[2])
      if (rows(rejranges)==0) {
        st_matrix("distcomprejranges", J(1,2,.))
        // rejranges = J(1,2,.)
      }
      else {
        rowstr = (J(rows(rejranges),1,""), J(rows(rejranges),1,"<"))
        rowstr[selectindex(rejranges[.,3]:==0), 2] = J(sum(rejranges[.,3]:==0),1,">")
        st_matrix("distcomprejranges",rejranges[. , 1..2])
        st_matrixrowstripe("distcomprejranges", rowstr)
      }
    }
  }

  // compute global p-value if desired
  if (pvalueflag) {
    p = distcompgofp(y0,y1)
    st_numscalar("distcompglobalpvalue", p)
  }
}


// compute confidence intervals at each order statistic
real matrix distcompCI(real scalar n, real scalar at) {
  real matrix ret
  ret = J(n,2,.)
  for (k=1; k<=n; k++) {
    ret[k,1] = invibeta(k, n+1-k,   at/2)
    ret[k,2] = invibeta(k, n+1-k, 1-at/2)
  }
  return(ret)
}


// remove duplicate values from y and CI (i.e., y0,CI0 or y1,CI1)
real matrix distcompuniqCI(real colvector y, real matrix CI) {
  // return matrix (ret) columns: y, CIlow, CIhigh
  real matrix ret
  real scalar i, cnt
  ret = (y[1], CI[1,.])
  cnt = 1 // row index for ret
  for (i=2; i<=length(y); i++) {
    if (y[i]==y[i-1]) { // duplicate y...
      ret[cnt,3] = CI[i,2] // ...only replace upper CI endpoint
    }
    else { // new y value, so make new row
      cnt++
      ret = ret \ (y[i], CI[i,.])
    }
  }
  return(ret)
}


// check global/GOF rejection
real scalar distcompgofrej(real colvector y0, real colvector y1, real matrix CI0, real matrix CI1) {
  real rowvector ind, n
  real scalar xy, tmp, n0, n1
  real matrix y, L, H
  n0 = length(y0)
  n1 = length(y1)
  n = (n0,n1)
  tmp = 1+max(n) // need 1+ to get infinity @ end of both
  y = J(tmp,2,.) // rem: . is like +Infinity
  L = J(tmp,2,.)
  H = J(tmp,2,.)
  y[1..n0,1] = y0;  L[1..n0,1] = CI0[.,1];  H[1..n0,1] = CI0[.,2]
  y[1..n1,2] = y1;  L[1..n1,2] = CI1[.,1];  H[1..n1,2] = CI1[.,2]
  ind = (1,1) // index counters for y0,y1
  xy = 1 // 1=y0, 2=y1
  // ensure y[1,xy]>y[1,3-xy]
  if (y[1,1] < y[1,2]) {
    xy = 2
  }
  while (ind[xy]<=n[xy]) {
    xy = 3-xy
    while (y[ind[xy]+1,xy] < y[ind[3-xy],3-xy]) {
      ind[xy] = ind[xy]+1
    }
    if (L[ind[xy],xy] > H[ind[3-xy],3-xy]) {
      return(1)
    }
    ind[xy] = ind[xy]+1
  }
  return(0) // if made it this far, don't reject
}


// compute global/GOF/goodness-of-fit two-sided p-value
//   y0 = sorted observed data, group #1
//   y1 = sorted observed data, group #2
real scalar distcompgofp(real colvector y0, real colvector y1) {
  real scalar ret // the global p-value to return
  real scalar n0, n1, TOL, alo, ahi, acur, rej, EPS // sample sizes; tolerance; alpha(tilde) bounds; etc.
  real matrix tmpmat0, tmpmat1
  n0 = length(y0)
  n1 = length(y1)
  // search for smallest alpha.tilde such that Reject
  TOL = 1.01 // stop when a.hi/a.lo<TOL
  EPS = 0.00000001 // a very very small number
  alo = 0.100
  ahi = 0.900
  // if necessary, decrease alo until fail to reject w/ alphatilde=alo
  rej = 1
  while (rej==1 & alo>EPS) {
    alo = alo/10
    CI0 = distcompCI(n0,alo)
    CI1 = distcompCI(n1,alo)
    tmpmat0 = distcompuniqCI(y0,CI0)
    tmpmat1 = distcompuniqCI(y1,CI1)
    rej = distcompgofrej(tmpmat0[.,1],tmpmat1[.,1],tmpmat0[.,2..3],tmpmat1[.,2..3])
  }
  if (alo<=EPS) { // alo is really close to zero, so just return
    return(distcompverify(alo,n0,n1))
  }
  // if necessary, increase ahi until reject w/ alphatilde=ahi
  rej = 0
  while ((rej==0) & (ahi < (1-EPS))) {
    ahi = 1-(1-ahi)/10
    CI0 = distcompCI(n0,ahi)
    CI1 = distcompCI(n1,ahi)
    tmpmat0 = distcompuniqCI(y0,CI0)
    tmpmat1 = distcompuniqCI(y1,CI1)
    rej = distcompgofrej(tmpmat0[.,1],tmpmat1[.,1],tmpmat0[.,2..3],tmpmat1[.,2..3])
  }
  if (ahi >= 1-EPS) { // ahi really close to 1, so just return
    return(distcompverify(ahi,n0,n1))
  }
  // at this point: don't reject w/ alo, do w/ ahi
  // next, increase alo and decrease ahi while maintaining these conditions
  // eventually, alo and ahi are very close, showing the alphatilde where
  // "barely" rejects; can compute the p-value from that alphatilde
  while (ahi/alo > TOL) {
    acur = (alo+ahi)/2
    CI0 = distcompCI(n0,acur)
    CI1 = distcompCI(n1,acur)
    tmpmat0 = distcompuniqCI(y0,CI0)
    tmpmat1 = distcompuniqCI(y1,CI1)
    rej = distcompgofrej(tmpmat0[.,1],tmpmat1[.,1],tmpmat0[.,2..3],tmpmat1[.,2..3])
    if (rej==0) {
      alo = acur
    }
    else {
      ahi = acur
    }
  }
  // simulate overall type I error rate for alphatilde found above
  // err on "conservative" side (ahi instead of alo; slightly higher p-value)
  ret = distcompverify(ahi,n0,n1)
  return(ret)
}


// simulate global/GOF type I error rate given alpha-tilde
real scalar distcompverify(real scalar atilde, real scalar n0, real scalar n1) {
  real scalar BLOCKSIZE, MINDRAWS, NDRAWS, irep, i, j, ret
  real colvector rejs
  real matrix CI0, CI1, OS0, OS1
  rseed(112358) // to be reproducible
  MINDRAWS = 1e4
  // constant parameters
  BLOCKSIZE = max((1,round(1e6/(n0+n1))))
  NDRAWS = BLOCKSIZE*ceil(MINDRAWS/BLOCKSIZE)
  // storage variables
  rejs = J(NDRAWS,1,.)
  CI0 = distcompCI(n0,atilde)
  CI1 = distcompCI(n1,atilde)
  for (irep=1;irep<=NDRAWS/BLOCKSIZE;irep++) {
    OS0 = rgamma(BLOCKSIZE,n0+1,1,1)
    for (i=1;i<=BLOCKSIZE;i++) {
      OS0[i,.] = runningsum(OS0[i,.]) / sum(OS0[i,.])
    }
    OS0 = OS0[.,1..n0]
    OS1 = rgamma(BLOCKSIZE,n1+1,1,1)
    for (i=1;i<=BLOCKSIZE;i++) {
      OS1[i,.] = runningsum(OS1[i,.]) / sum(OS1[i,.])
    }
    OS1 = OS1[.,1..n1]
    for (j=1;j<=BLOCKSIZE;j++) {
      rejs[BLOCKSIZE*(irep-1)+j] = distcompgofrej(OS0[j,.]',OS1[j,.]',CI0,CI1)
    }
  }
  ret = mean(rejs)
  return(ret)
}


// given CIs and order statistics (sorted values), determine 
//   statistically significantly different ranges of values.
// os0 and os1 should (each) have unique values.
real matrix distcomprejranges(real colvector os0, real colvector os1, real matrix CI0, real matrix CI1) {
  real matrix ret
  real colvector r1a, r3a, r4a, r1, r3, r4, intfrom, intto
  real rowvector tmprow
  string colvector r2a, r2
  real vector tmp0, tmp1
  real scalar i, i2
  ret = J(0,3,.)
  CI0 = (-999, .) \ CI0 \ (., 999)
  CI1 = (-999, .) \ CI1 \ (., 999)
  r1a = os0\os1
  r2a = J(length(os0),1,"y0") \ J(length(os1),1,"y1")
  // sort r1a and r2a by value of (pooled) order statistics
  r2a = r2a[order(r1a,1), .]
  r1a = sort(r1a, 1)
  tmp0 = r2a:=="y0"
  tmp1 = r2a:=="y1"
  r3a = J(length(r1a), 1, .) // store cumsum of tmp0
  r4a = J(length(r1a), 1, .) // store cumsum of tmp1
  r3a[1] = 0+tmp0[1]
  r4a[1] = 0+tmp1[1]
  for (i=2; i<=rows(r3a); i++) {
    r3a[i] = r3a[i-1]+tmp0[i]
    r4a[i] = r4a[i-1]+tmp1[i]
  }
  // deal with duplicates
  v = J(length(r1a),1,1)
  for (i=2;i<=length(r1a);i++) {
    if (r1a[i]==r1a[i-1]) v[i-1]=0
  }
  r1 = r3 = r4 = J(sum(v),1,.)
  r2 = J(sum(v),1,"")
  for (i=i2=1; i<=length(r1a); i++) {
    if (v[i]) {
      r1[i2] = r1a[i]; r3[i2] = r3a[i]; r4[i2] = r4a[i]
      r2[i2] = r2a[i]
      if (i>1) {
        if (v[i-1]==0) r2[i2]="01" //source = both y0 and y1
      }
      i2++
    }
  }
  // set up potential ranges
  intfrom = (r1[1]-999) \ r1
  intto   = r1 \ (r1[length(r1)]+999)
  for (i=1; i<=rows(r3); i++) {
    if ((CI0[r3[i]+1,1]>CI1[r4[i]+1+1,2]) | (CI0[r3[i]+1+1,2]<CI1[r4[i]+1,1])) {
      tmp = (rows(ret)>0)?(ret[rows(ret),2]==intfrom[i+1]):(0)
      if (tmp) {
        ret[rows(ret),2] = intto[i+1]
      }
      else {
        tmprow = (intfrom[i+1], intto[i+1], (CI0[r3[i]+1,1]>CI1[r4[i]+1+1,2]))
        ret = ret \ tmprow
      }
    }
    else if (r2[i]=="01") {
      if ((CI0[r3[i]+1,1]>CI1[r4[i]+1,2]) | (CI0[r3[i]+1,2]<CI1[r4[i]+1,1])) {
        tmp = (rows(ret)>0)?(ret[rows(ret),2]==intfrom[i+1]):(0)
        if (!tmp) {
          tmprow = (intfrom[i+1], intfrom[i+1], (CI0[r3[i]+1,1]>CI1[r4[i]+1,2]))
          ret = ret \ tmprow
        }
      }
    }
  }
  return(ret)
}


// retrieve alpha.tilde (and alpha.sim) from lookup table
real colvector distcompalpha(real scalar n0, real scalar n1, real scalar alphaperc, real matrix LOOKUP) {
  real scalar alpha
  real colvector ret, n
  alpha = alphaperc / 100
  ret = J(2,1,.)
  n = (min((n0,n1)),max((n0,n1)))'
  // Formula: good if n0==n1 and n0,n1>=200, o/w conservative
  if (alphaperc==1) {
    ret = (exp(0.02576944-3.37109911*sqrt(ln(ln(max(n))))), .)'
  }
  else if (alphaperc==5) {
    ret = (exp(0.6872947-3.1503102*sqrt(ln(ln(max(n))))), .)'
  }
  else if (alphaperc==10) {
    ret = (exp(1.081619-3.125037*sqrt(ln(ln(max(n))))), .)'
  }
  if (n[1]/n[2]<0.5) {
    if (n[1]/n[2]<0.1) {
      ret[1] = ret[1]*(1/2)*((n[1]/n[2])/0.1) // from 0 to 1/2 as n1/n2 from 0 to 0.1
    }
    else {
      ret[1] = ret[1]*((n[1]/n[2]+0.3)/0.8) // from 0.5 to 1 as n1/n2 from 0.1 to 0.5
    }
  }
  if ((max(n)>=1000 & n[1]/n[2]>0.9) | (max(n)>100000 & n[1]/n[2]>0.5)) {
    return(ret)
  }
  // Otherwise use lookup table
  // First filter by alpha
  L = select(LOOKUP, LOOKUP[.,1]:==alpha)
  if (rows(L)==0) {
    _error("Need alpha=0.10 or 0.05 or 0.01 or else use the more functional R code from the author's website.")
  }
  // Second filter by n
  L = select(L, (L[.,2]:>=n[1]) :* (L[.,3]:>=n[2]))
  if (rows(L)==0) {
    return(ret) // sample sizes very large; use formula
  }
  // Third find alpha.tilde
  biggest = max(L[.,4])
  L = select(L, L[.,4] :== biggest)
  if (L[1,4]*1.01>ret[1] | (min(n)<200)) {
    ret[1] = L[1,4]
    ret[2] = L[1,5]
    if (L[1,5]!=L[1,6]) { // err on conservative side
      ret[1] = ret[1] - 0.5*10^(-8)
    }
  }
  return(ret)
}


// "load" lookup table for critical values
// columns: "ALPHA","nx","ny","alpha.tilde","ALPHA.simulated.lo","ALPHA.simulated.hi"
GoldmanKaplan2sLookup = (0.010,      5,     10,0.07883072,0.00999300,0.00999300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      5,     10,0.13562066,0.03956000,0.05944000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      5,     10,0.21463444,0.08753500,0.12874000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      9,     10,0.05366823,0.00696100,0.01143400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      9,     10,0.12543036,0.04372000,0.05807000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      9,     10,0.15284111,0.08454000,0.10606000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.190,      9,     10,0.24567187,0.16892500,0.20262000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.200,      9,     10,0.24567187,0.16892500,0.20262000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     10,     10,0.05041165,0.00650100,0.01219400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,     10,0.10937500,0.04419000,0.05253000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,     10,0.18032046,0.08845500,0.13192000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      6,     11,0.07164299,0.00592000,0.01320700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      6,     11,0.13489221,0.04763000,0.06341000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      6,     11,0.18484967,0.09041000,0.12367000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     10,     11,0.05023837,0.00753100,0.01108700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,     11,0.11329342,0.04401500,0.05877000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,     11,0.15663986,0.08932000,0.11123500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     11,     11,0.05954557,0.00944900,0.01716400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     11,     11,0.11084449,0.03529500,0.05612000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     11,     11,0.13639945,0.07553500,0.11014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      6,     12,0.06130128,0.00956300,0.01481200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      6,     12,0.15351700,0.04553500,0.06786500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      6,     12,0.16695368,0.09089000,0.11871000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     11,     12,0.04783729,0.00834500,0.01087800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     11,     12,0.09819940,0.04681500,0.05359000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     11,     12,0.15965519,0.08833500,0.11061500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     12,     12,0.04487251,0.00778300,0.01339700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     12,     12,0.11920465,0.04631000,0.06845500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     12,     12,0.14082907,0.09199000,0.12679500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      6,     13,0.05055340,0.00683600,0.01062900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      6,     13,0.12712743,0.05009500,0.05009500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      6,     13,0.15670620,0.09241000,0.10860000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,     13,0.11008032,0.04874500,0.05852500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,     13,0.16313201,0.09272500,0.11812000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.190,     10,     13,0.20747598,0.18806000,0.18806000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.200,     10,     13,0.20764265,0.18806000,0.20917500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     12,     13,0.04960560,0.00856700,0.01128400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     12,     13,0.10086736,0.04725500,0.05558000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     12,     13,0.14779396,0.09228500,0.10643500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     13,     13,0.04697284,0.00873300,0.01263700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     13,     13,0.08764463,0.04494000,0.05510500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     13,     13,0.14452714,0.08150500,0.11873500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      7,     14,0.05257338,0.00833400,0.01175200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      7,     14,0.11634852,0.03952500,0.05349500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      7,     14,0.16677613,0.08185000,0.10399500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     13,     14,0.03791852,0.00974500,0.00974500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     13,     14,0.09976344,0.04697000,0.05682500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     13,     14,0.12951968,0.09138000,0.10634500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     14,     14,0.04449917,0.00717800,0.01160100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     14,     14,0.08784927,0.03579000,0.05190000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     14,     14,0.14766166,0.09678500,0.13392000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      8,     15,0.04474466,0.00836400,0.01128400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      8,     15,0.10915709,0.04955500,0.06095000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      8,     15,0.16208016,0.08430000,0.10552000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     14,     15,0.04142360,0.00921200,0.01081100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     14,     15,0.08504160,0.04702500,0.05045000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     14,     15,0.13342492,0.08550500,0.10133500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     15,     15,0.03828541,0.01027500,0.01027500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     15,     15,0.09044883,0.04356000,0.06024500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     15,     15,0.13689649,0.09054500,0.11288000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      8,     16,0.04377202,0.00820400,0.01045300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      8,     16,0.11200327,0.04568000,0.05502000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      8,     16,0.16860107,0.09328000,0.11009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     14,     16,0.03824945,0.00904200,0.01098200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     14,     16,0.09549385,0.04529500,0.05116500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     14,     16,0.12104334,0.09364500,0.10691500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     16,     16,0.03744230,0.00858500,0.01115500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     16,     16,0.08720697,0.04104500,0.05232500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     16,     16,0.13029249,0.09595500,0.10755000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      8,     17,0.04481004,0.00775300,0.01055200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      8,     17,0.10110639,0.04900000,0.05863500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      8,     17,0.15035843,0.10086500,0.10086500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     15,     17,0.04080579,0.00865400,0.01091000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     15,     17,0.07848953,0.04826000,0.05147000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     15,     17,0.12494437,0.09574000,0.10952000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     17,     17,0.03315527,0.00774700,0.01073000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     17,     17,0.08593234,0.04475000,0.05114000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     17,     17,0.13105376,0.09222000,0.10665000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      9,     18,0.03905977,0.00879700,0.01044700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      9,     18,0.09185174,0.04967500,0.05502500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      9,     18,0.13995187,0.09821500,0.10753500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     16,     18,0.03844994,0.00946000,0.01072700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     16,     18,0.08070926,0.04962500,0.05331500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     16,     18,0.12302053,0.09757500,0.10379500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     18,     18,0.03439859,0.01021600,0.01021600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     18,     18,0.08685004,0.04319000,0.05113000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     18,     18,0.11955723,0.08961000,0.10295500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     10,     19,0.04307253,0.00929300,0.01132100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,     19,0.09367219,0.04762500,0.05426500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,     19,0.12751260,0.08855500,0.10107000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     17,     19,0.03428966,0.01023400,0.01023400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     17,     19,0.07869861,0.04779500,0.05172000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     17,     19,0.12146432,0.10072500,0.10072500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     19,     19,0.03566786,0.00861400,0.01208400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     19,     19,0.09214715,0.04915500,0.05741500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     19,     19,0.10530862,0.09488500,0.10172500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      2,     20,0.09539541,0.00857700,0.02588300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      2,     20,0.14012770,0.02598000,0.05268000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      2,     20,0.24262768,0.08763000,0.13106500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     10,     20,0.04020026,0.00826000,0.01070800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,     20,0.09367144,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,     20,0.14209794,0.09438500,0.10974000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     18,     20,0.03276377,0.01031800,0.01031800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     18,     20,0.08022552,0.04818500,0.05211000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     18,     20,0.11837764,0.09199500,0.10402000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     20,     20,0.03652078,0.00855500,0.01065700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     20,     20,0.08195314,0.04946500,0.05681000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     20,     20,0.10722372,0.09523500,0.10366500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     10,     21,0.03729101,0.00975400,0.00975400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,     21,0.08335200,0.04601000,0.05086500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,     21,0.13791812,0.09312500,0.10215000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     19,     21,0.03234930,0.01016600,0.01016600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     19,     21,0.07534775,0.04564500,0.05150000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     19,     21,0.11711607,0.09741000,0.10152000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     21,     21,0.03652078,0.01022000,0.01022000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     21,     21,0.07682318,0.04961000,0.05471000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     21,     21,0.10113651,0.09203500,0.10271500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     11,     22,0.03839467,0.00967100,0.00967100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     11,     22,0.08925163,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     11,     22,0.12751738,0.09392000,0.10154500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     20,     22,0.02942867,0.00985900,0.00985900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     20,     22,0.07587098,0.04630500,0.05218500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     20,     22,0.11665669,0.09674000,0.10126000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     22,     22,0.03036378,0.00938500,0.01042700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     22,     22,0.07605465,0.04987000,0.04987000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     22,     22,0.10312963,0.09188500,0.10343500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     12,     23,0.03424037,0.01015200,0.01015200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     12,     23,0.08986804,0.04930500,0.05412500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     12,     23,0.11907929,0.09827000,0.10469500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     21,     23,0.03052909,0.00999900,0.00999900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     21,     23,0.07633909,0.04582000,0.05156500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     21,     23,0.11518099,0.10033000,0.10033000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     23,     23,0.03145259,0.00955600,0.01086600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     23,     23,0.06740060,0.04486500,0.05069000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     23,     23,0.10312881,0.10082000,0.10082000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     12,     24,0.03801016,0.00844500,0.01040600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     12,     24,0.08473471,0.04770500,0.05204000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     12,     24,0.11807130,0.09748500,0.10424500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     22,     24,0.03143262,0.00977100,0.00977100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     22,     24,0.07676033,0.04755000,0.05374500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     22,     24,0.11005543,0.09930000,0.09930000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     24,     24,0.02859327,0.00971300,0.00971300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     24,     24,0.06654799,0.05012000,0.05012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     24,     24,0.10382989,0.09088000,0.10986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     12,     25,0.04039230,0.00986500,0.00986500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     12,     25,0.08658184,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     12,     25,0.11984642,0.09545000,0.10635500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     22,     25,0.02878246,0.01005000,0.01005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     22,     25,0.07585043,0.04916000,0.05178000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     22,     25,0.11218602,0.10057000,0.10057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     25,     25,0.02793872,0.00953700,0.01087200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     25,     25,0.06745792,0.04924000,0.05251500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     25,     25,0.10470660,0.09222000,0.11080500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     13,     26,0.03602185,0.01005900,0.01005900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     13,     26,0.08188472,0.04941000,0.05285500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     13,     26,0.11304094,0.09674500,0.10655000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     23,     26,0.02974848,0.00933100,0.01051600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     23,     26,0.07553085,0.04870500,0.05137000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     23,     26,0.10362062,0.09973500,0.09973500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     26,     26,0.02793872,0.01007300,0.01007300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     26,     26,0.06678307,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     26,     26,0.10551421,0.09281000,0.11204500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     14,     27,0.03212429,0.01009400,0.01009400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     14,     27,0.07726284,0.04993500,0.04993500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     14,     27,0.11073685,0.09777500,0.10248000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     24,     27,0.03068241,0.00922900,0.01045700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     24,     27,0.06724133,0.04901500,0.05140000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     24,     27,0.09567670,0.09872500,0.10305500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     27,     27,0.02793872,0.01030600,0.01030600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     27,     27,0.06719663,0.04470000,0.05402500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     27,     27,0.10551337,0.09958500,0.09958500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     14,     28,0.03020141,0.00922100,0.01048600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     14,     28,0.08425408,0.04934500,0.05589000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     14,     28,0.10764797,0.09529500,0.10136500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     25,     28,0.02736258,0.01008700,0.01008700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     25,     28,0.06559306,0.04966000,0.05131500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     25,     28,0.09663232,0.09940000,0.09940000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     28,     28,0.02723296,0.00947500,0.01042400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     28,     28,0.06782768,0.04892500,0.05806500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     28,     28,0.10081803,0.10080000,0.10080000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     14,     29,0.03367993,0.00950000,0.01046800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     14,     29,0.08048972,0.04959500,0.05280500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     14,     29,0.10752308,0.09900000,0.10464000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     26,     29,0.02763587,0.01028100,0.01028100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     26,     29,0.06702292,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     26,     29,0.09633063,0.09853000,0.10291000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     29,     29,0.02688140,0.00882800,0.01079300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     29,     29,0.06797208,0.04888000,0.05361000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     29,     29,0.10147628,0.09895500,0.10812500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      3,     30,0.05568670,0.00743400,0.01302900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      3,     30,0.11294271,0.04064500,0.05835000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      3,     30,0.16396845,0.08594500,0.11073000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     15,     30,0.03061811,0.00989100,0.00989100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     15,     30,0.07544902,0.04937500,0.05199000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     15,     30,0.10557414,0.10027000,0.10027000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     27,     30,0.02791190,0.00975700,0.00975700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     27,     30,0.06497416,0.04804500,0.05050000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     27,     30,0.09661307,0.09869500,0.10311000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     30,     30,0.02688140,0.01000500,0.01000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     30,     30,0.06591460,0.04853500,0.05070000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     30,     30,0.09796100,0.10054000,0.10054000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     16,     31,0.03014862,0.00937800,0.01062700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     16,     31,0.07089002,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     16,     31,0.10322989,0.08988000,0.10104000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     28,     31,0.02791168,0.00984400,0.00984400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     28,     31,0.06373251,0.04972500,0.05172500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     28,     31,0.09154451,0.09925000,0.09925000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     31,     31,0.02764425,0.00959600,0.01167200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     31,     31,0.06819482,0.04832000,0.05093000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     31,     31,0.09963582,0.09651500,0.10109500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     16,     32,0.02937777,0.01017300,0.01017300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     16,     32,0.07019676,0.04833500,0.05082000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     16,     32,0.10368603,0.09774000,0.10151500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     29,     32,0.02555838,0.00976400,0.00976400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     29,     32,0.05875128,0.04883000,0.05104000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     29,     32,0.09146409,0.09890000,0.10288000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     32,     32,0.02701598,0.00997700,0.00997700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     32,     32,0.06785148,0.04939500,0.05209500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     32,     32,0.09821292,0.09784000,0.10237500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     16,     33,0.02687398,0.00998400,0.00998400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     16,     33,0.07275801,0.04970500,0.05206500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     16,     33,0.10126934,0.09701500,0.10209000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     30,     33,0.02442103,0.00980000,0.00980000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     30,     33,0.05999471,0.04861000,0.05093000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     30,     33,0.09207898,0.09471000,0.10206000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     33,     33,0.02701598,0.01026000,0.01026000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     33,     33,0.06483209,0.05017000,0.05017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     33,     33,0.09392331,0.09872000,0.10303500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     17,     34,0.02956138,0.01008200,0.01008200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     17,     34,0.06765938,0.04969000,0.05171500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     17,     34,0.10010816,0.09907000,0.10173500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     31,     34,0.02490906,0.01010100,0.01010100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     31,     34,0.06117048,0.04916000,0.05154500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     31,     34,0.09304387,0.09582500,0.10342500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     34,     34,0.02344362,0.00992500,0.00992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     34,     34,0.06020868,0.04801000,0.05048000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     34,     34,0.09245372,0.09897500,0.10462500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     18,     35,0.02888953,0.01019000,0.01019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     18,     35,0.06495436,0.04868500,0.05197500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     18,     35,0.10255059,0.09912000,0.09912000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     32,     35,0.02490886,0.00999800,0.00999800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     32,     35,0.05967780,0.04947500,0.05096500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     32,     35,0.09395437,0.09803000,0.10550000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     35,     35,0.02344362,0.00970300,0.00970300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     35,     35,0.06081004,0.05007000,0.05007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     35,     35,0.08881165,0.09682000,0.10102000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     18,     36,0.02745692,0.01026800,0.01026800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     18,     36,0.06250671,0.04845000,0.05070000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     18,     36,0.10029446,0.09247000,0.10357000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     32,     36,0.02459376,0.01008600,0.01008600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     32,     36,0.05888910,0.04901500,0.05244500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     32,     36,0.08949165,0.09665000,0.10371500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     36,     36,0.02344362,0.00978500,0.00978500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     36,     36,0.06120792,0.04904000,0.05114500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     36,     36,0.09055462,0.09817000,0.10234000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     18,     37,0.02753864,0.00996800,0.00996800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     18,     37,0.06880470,0.04901000,0.05186500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     18,     37,0.09670124,0.09786500,0.10203500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     33,     37,0.02369517,0.00992300,0.00992300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     33,     37,0.05888863,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     33,     37,0.09044173,0.09692500,0.10383500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     37,     37,0.02311061,0.01012200,0.01012200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     37,     37,0.05848416,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     37,     37,0.08964871,0.09939500,0.09939500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     19,     38,0.02628688,0.01017000,0.01017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     19,     38,0.06450834,0.04923500,0.05075500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     19,     38,0.09863371,0.10012500,0.10012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     34,     38,0.02416869,0.01000300,0.01000300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     34,     38,0.05882698,0.04804000,0.05147000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     34,     38,0.09089303,0.09973500,0.09973500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     38,     38,0.02339949,0.01021800,0.01021800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     38,     38,0.05673848,0.04902000,0.05115500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     38,     38,0.08565934,0.10080500,0.10080500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     20,     39,0.02628688,0.01004600,0.01004600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     20,     39,0.06291180,0.04909500,0.05024000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     20,     39,0.10271158,0.09795500,0.10091500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     35,     39,0.02309318,0.01026600,0.01026600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     35,     39,0.05879762,0.04861500,0.05224000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     35,     39,0.08880903,0.09525500,0.10151000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     39,     39,0.02369199,0.00995100,0.00995100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     39,     39,0.05482653,0.04827000,0.05194500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     39,     39,0.08252956,0.09944000,0.09944000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      4,     40,0.03824551,0.00910600,0.01193500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      4,     40,0.09334108,0.05011500,0.05011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      4,     40,0.12231297,0.09234500,0.10172000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     20,     40,0.02628688,0.01004600,0.01004600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     20,     40,0.06328090,0.04816000,0.05116500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     20,     40,0.09647202,0.09780000,0.10161000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     36,     40,0.02309300,0.01011600,0.01011600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     36,     40,0.05829269,0.04835000,0.05180500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     36,     40,0.08870324,0.09603000,0.10233500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,     40,0.02369199,0.01007300,0.01007300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,     40,0.05484176,0.04982500,0.04982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,     40,0.08240133,0.09847000,0.10496000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     20,     41,0.02479331,0.01020100,0.01020100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     20,     41,0.06068562,0.04973000,0.05161000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     20,     41,0.09806899,0.09803500,0.10817000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     37,     41,0.02355449,0.01017200,0.01017200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     37,     41,0.05685594,0.04973500,0.05135500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     37,     41,0.08555053,0.10017000,0.10017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     41,     41,0.02369199,0.01031400,0.01031400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     41,     41,0.05570921,0.04824500,0.05200500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     41,     41,0.08289257,0.09847000,0.10505000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     21,     42,0.02629105,0.00935700,0.01035100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     21,     42,0.06197836,0.04904500,0.05054500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     21,     42,0.09649356,0.09560000,0.10221500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     38,     42,0.02317169,0.01018000,0.01018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     38,     42,0.05791406,0.04936500,0.05109000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     38,     42,0.08597743,0.10071000,0.10071000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     42,     42,0.02315353,0.01007000,0.01007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     42,     42,0.05611924,0.04930500,0.05319000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     42,     42,0.08289191,0.09982000,0.09982000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     22,     43,0.02629105,0.00973800,0.00973800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     22,     43,0.06197787,0.05000000,0.05000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     22,     43,0.09280856,0.09587000,0.10217500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     39,     43,0.02317151,0.00986600,0.00986600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     39,     43,0.05869053,0.04979500,0.05317000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     39,     43,0.08683617,0.10047000,0.10047000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     43,     43,0.02315353,0.01027600,0.01027600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     43,     43,0.05525376,0.04817500,0.05142000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     43,     43,0.08175491,0.09849500,0.10141500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     22,     44,0.02509601,0.01010100,0.01010100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     22,     44,0.06086008,0.04948500,0.05076000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     22,     44,0.09259217,0.09824000,0.10209500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,     44,0.02293970,0.01018200,0.01018200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,     44,0.05839099,0.04953000,0.05036500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,     44,0.08683547,0.09918500,0.09918500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     44,     44,0.02210110,0.01015900,0.01015900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     44,     44,0.05575667,0.04917500,0.05224500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     44,     44,0.08175426,0.09933000,0.09933000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     22,     45,0.02509601,0.01032000,0.01032000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     22,     45,0.05912100,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     22,     45,0.09668617,0.09902500,0.10128000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,     45,0.02339813,0.01009000,0.01009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,     45,0.05582848,0.04973000,0.05099500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,     45,0.08262558,0.10031000,0.10031000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     45,     45,0.02210110,0.01030300,0.01030300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     45,     45,0.05266944,0.04848500,0.05021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     45,     45,0.08138585,0.09756000,0.10287500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     23,     46,0.02309973,0.01003700,0.01003700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     23,     46,0.05649012,0.04993000,0.04993000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     23,     46,0.09392337,0.09967000,0.09967000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     41,     46,0.02235691,0.00973900,0.00973900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     41,     46,0.05588165,0.04905000,0.05036000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     41,     46,0.08314112,0.10012000,0.10012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     46,     46,0.02122208,0.01005100,0.01005100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     46,     46,0.05319551,0.04990000,0.04990000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     46,     46,0.08138520,0.09961500,0.09961500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     24,     47,0.02309973,0.00998300,0.00998300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     24,     47,0.05864881,0.04895500,0.05027500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     24,     47,0.09012470,0.09910500,0.10275500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     42,     47,0.02207410,0.01005800,0.01005800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     42,     47,0.05576283,0.04952500,0.05021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     42,     47,0.08314046,0.09918000,0.09918000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     47,     47,0.02122208,0.00974500,0.00974500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     47,     47,0.05383821,0.04941000,0.05050000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     47,     47,0.07776356,0.09984500,0.09984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     24,     48,0.02309973,0.00986200,0.00986200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     24,     48,0.05741028,0.04907500,0.05030000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     24,     48,0.09372894,0.10079000,0.10079000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     43,     48,0.02207392,0.01025200,0.01025200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     43,     48,0.05372540,0.05002000,0.05002000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     43,     48,0.08313979,0.09947000,0.09947000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     48,     48,0.02039966,0.00931500,0.01039700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     48,     48,0.05264558,0.04802000,0.05027000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     48,     48,0.07854026,0.10071000,0.10071000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     24,     49,0.02309973,0.00984400,0.00984400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     24,     49,0.05890578,0.04955500,0.05263000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     24,     49,0.08955800,0.09993500,0.09993500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     44,     49,0.02207374,0.00989400,0.00989400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     44,     49,0.05307707,0.04848500,0.05028500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     44,     49,0.07944007,0.10077500,0.10077500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     49,     49,0.02052716,0.01018300,0.01018300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     49,     49,0.05264515,0.04986500,0.04986500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     49,     49,0.07853963,0.09994500,0.09994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      5,     50,0.03160786,0.01003100,0.01003100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      5,     50,0.07239324,0.04188000,0.05196500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      5,     50,0.11258353,0.09963000,0.09963000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     25,     50,0.02338848,0.01021000,0.01021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     25,     50,0.05722255,0.04982500,0.04982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     25,     50,0.08673147,0.10011500,0.10011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     45,     50,0.02251486,0.01009200,0.01009200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     45,     50,0.05251203,0.04967500,0.05022500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     45,     50,0.07864535,0.10034500,0.10034500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,     50,0.02063983,0.00942900,0.01053400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,     50,0.05050620,0.04939500,0.05060000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,     50,0.07606919,0.10001000,0.10001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     26,     51,0.02232537,0.00983500,0.00983500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     26,     51,0.05628594,0.04688000,0.05061000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     26,     51,0.08563432,0.10058500,0.10058500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     46,     51,0.02007876,0.00994900,0.00994900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     46,     51,0.05305016,0.04955500,0.05138500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     46,     51,0.07702428,0.10032000,0.10032000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     51,     51,0.02063983,0.00992100,0.00992100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     51,     51,0.04927008,0.04640500,0.05119000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     51,     51,0.07653919,0.09821000,0.10205000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     26,     52,0.02181797,0.01011200,0.01011200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     26,     52,0.05652322,0.04948500,0.05062500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     26,     52,0.08734563,0.10036500,0.10036500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     47,     52,0.02048001,0.01026400,0.01026400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     47,     52,0.05303690,0.04841000,0.05022000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     47,     52,0.07817856,0.10081000,0.10081000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     52,     52,0.02063983,0.01018000,0.01018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     52,     52,0.04942678,0.04584000,0.05072000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     52,     52,0.07653858,0.09931500,0.09931500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     26,     53,0.02181797,0.01004800,0.01004800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     26,     53,0.05567525,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     26,     53,0.08415424,0.10040000,0.10040000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     48,     53,0.02022094,0.01014100,0.01014100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     48,     53,0.05300334,0.04985500,0.04985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     48,     53,0.07817794,0.09928000,0.09928000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     53,     53,0.02017074,0.01007000,0.01007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     53,     53,0.04957759,0.04572500,0.05064000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     53,     53,0.07596415,0.10044000,0.10044000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     27,     54,0.02209070,0.01023600,0.01023600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     27,     54,0.05650960,0.04981500,0.04981500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     27,     54,0.08289176,0.09978000,0.09978000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     49,     54,0.02022078,0.00997700,0.00997700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     49,     54,0.05301087,0.04948000,0.05123500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     49,     54,0.07718899,0.10019500,0.10019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     54,     54,0.02017074,0.01017100,0.01017100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     54,     54,0.04972283,0.04648500,0.05134500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     54,     54,0.07598982,0.09364000,0.10383500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     28,     55,0.02209070,0.01005700,0.01005700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     28,     55,0.05578541,0.04999500,0.04999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     28,     55,0.08184318,0.10041000,0.10041000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,     55,0.01996498,0.01027200,0.01027200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,     55,0.05096023,0.04955500,0.05044000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,     55,0.07718837,0.10013500,0.10013500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     55,     55,0.02017074,0.01009000,0.01009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     55,     55,0.04986281,0.04694500,0.05197500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     55,     55,0.07614884,0.09353000,0.10370500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     28,     56,0.02158864,0.00985500,0.00985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     28,     56,0.05495981,0.04881000,0.05233000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     28,     56,0.08184252,0.09995500,0.09995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,     56,0.01996482,0.01021000,0.01021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,     56,0.05121452,0.04996500,0.04996500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,     56,0.07873090,0.10021000,0.10021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     56,     56,0.01971231,0.00973600,0.00973600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     56,     56,0.04999780,0.04781000,0.05283500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     56,     56,0.07630215,0.09178000,0.10195000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     28,     57,0.02134331,0.01007900,0.01007900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     28,     57,0.05456686,0.04944500,0.05026500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     28,     57,0.08184187,0.09923500,0.09923500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     51,     57,0.01996466,0.01004400,0.01004400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     51,     57,0.05122398,0.04977500,0.05038000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     51,     57,0.07873027,0.10085500,0.10085500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     57,     57,0.01971231,0.01017400,0.01017400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     57,     57,0.05012807,0.04788000,0.05281500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     57,     57,0.07645006,0.09432000,0.10430000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     29,     58,0.02134331,0.00995000,0.00995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     29,     58,0.05511187,0.05012000,0.05012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     29,     58,0.07950324,0.10063000,0.10063000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     52,     58,0.01996450,0.01011300,0.01011300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     52,     58,0.05025692,0.04965000,0.05031500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     52,     58,0.07773433,0.10058500,0.10058500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     58,     58,0.01971231,0.01032800,0.01032800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     58,     58,0.05012767,0.04991500,0.04991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     58,     58,0.07659283,0.09580500,0.10574500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     30,     59,0.02134331,0.00967800,0.00967800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     30,     59,0.05336811,0.04963000,0.05039500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     30,     59,0.07644046,0.09893000,0.10122000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     53,     59,0.01939402,0.01028900,0.01028900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     53,     59,0.04822058,0.05000500,0.05000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     53,     59,0.07613203,0.10039000,0.10039000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     59,     59,0.01926431,0.01016400,0.01016400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     59,     59,0.04962620,0.04999500,0.04999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     59,     59,0.07673074,0.09822000,0.10859000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      6,     60,0.02873442,0.01020500,0.01020500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      6,     60,0.06827473,0.04739500,0.05242000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      6,     60,0.09537330,0.09681500,0.10136500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     30,     60,0.02085824,0.00971400,0.00971400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     30,     60,0.05393218,0.04921500,0.05026000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     30,     60,0.07864513,0.09642000,0.10128500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     54,     60,0.01939386,0.01008000,0.01008000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     54,     60,0.04882271,0.05016000,0.05016000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     54,     60,0.07498990,0.09937500,0.09937500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     60,     60,0.01926431,0.01018800,0.01018800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     60,     60,0.04987956,0.04992500,0.04992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     60,     60,0.07427410,0.09934500,0.09934500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     30,     61,0.02085824,0.01013600,0.01013600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     30,     61,0.05385534,0.04947000,0.05283000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     30,     61,0.08165887,0.09888000,0.10376500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     55,     61,0.01914853,0.01012600,0.01012600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     55,     61,0.04857830,0.04996000,0.04996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     55,     61,0.07135430,0.09942500,0.09942500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     61,     61,0.01926431,0.01023700,0.01023700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     61,     61,0.05059415,0.04973000,0.05095500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     61,     61,0.07331623,0.09976500,0.09976500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     31,     62,0.02085824,0.00968800,0.00968800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     31,     62,0.05267654,0.04981000,0.04981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     31,     62,0.07915502,0.09760000,0.10246500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     56,     62,0.01914838,0.00992700,0.00992700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     56,     62,0.04825924,0.04981500,0.04981500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     56,     62,0.07278024,0.10081500,0.10081500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     62,     62,0.01926431,0.00977600,0.00977600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     62,     62,0.05016813,0.04957500,0.05049500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     62,     62,0.07331564,0.09963000,0.09963000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     32,     63,0.02085824,0.01003900,0.01003900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     32,     63,0.05237724,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     32,     63,0.07682677,0.09631000,0.10093000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     57,     63,0.01953104,0.01020100,0.01020100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     57,     63,0.04688024,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     57,     63,0.07277966,0.10014500,0.10014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     63,     63,0.01932941,0.00966500,0.01033600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     63,     63,0.04793565,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     63,     63,0.07369630,0.09881000,0.10099500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     32,     64,0.02038418,0.01006100,0.01006100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     32,     64,0.05292965,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     32,     64,0.07874744,0.09978500,0.09978500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     58,     64,0.01928397,0.01025700,0.01025700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     58,     64,0.04702738,0.04936000,0.05064500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     58,     64,0.07205157,0.09999000,0.09999000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     64,     64,0.01932941,0.00989200,0.00989200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     64,     64,0.04700689,0.04982500,0.04982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     64,     64,0.07369571,0.09963000,0.09963000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     32,     65,0.02038418,0.00972000,0.00972000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     32,     65,0.05172671,0.05008000,0.05008000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     32,     65,0.07651029,0.10012500,0.10012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     58,     65,0.01928382,0.00994100,0.00994100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     58,     65,0.04700507,0.04979000,0.05065500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     58,     65,0.07133077,0.10009000,0.10009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     65,     65,0.01932941,0.01024100,0.01024100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     65,     65,0.04677157,0.05000500,0.05000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     65,     65,0.07369512,0.09970500,0.09970500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     33,     66,0.02038418,0.00984700,0.00984700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     33,     66,0.05241532,0.04973500,0.05084500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     33,     66,0.07503622,0.09893000,0.10128000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     59,     66,0.01928366,0.00980200,0.00980200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     59,     66,0.04566190,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     59,     66,0.07133020,0.10017000,0.10017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     66,     66,0.01932941,0.01015500,0.01015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     66,     66,0.04715474,0.04918000,0.05020000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     66,     66,0.07369453,0.09911500,0.09911500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     34,     67,0.01945763,0.00983200,0.00983200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     34,     67,0.05041002,0.04978000,0.05038000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     34,     67,0.07785007,0.09994000,0.09994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     60,     67,0.01928351,0.00988300,0.00988300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     60,     67,0.04587982,0.04980500,0.05109500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     60,     67,0.07061661,0.10044500,0.10044500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     67,     67,0.01932941,0.01022600,0.01022600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     67,     67,0.04748866,0.04980500,0.05107500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     67,     67,0.07276229,0.10055500,0.10055500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     34,     68,0.02043051,0.01013300,0.01013300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     34,     68,0.04897792,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     34,     68,0.07519609,0.10060000,0.10060000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     61,     68,0.01903957,0.01003000,0.01003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     61,     68,0.04542083,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     61,     68,0.07061604,0.10043500,0.10043500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     68,     68,0.01932941,0.01014800,0.01014800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     68,     68,0.04725093,0.04988500,0.04988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     68,     68,0.07203438,0.09984500,0.09984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     34,     69,0.01996618,0.01005300,0.01005300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     34,     69,0.04972664,0.04965000,0.05024500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     34,     69,0.07519609,0.10080000,0.10080000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     62,     69,0.01903942,0.01010400,0.01010400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     62,     69,0.04499482,0.04985500,0.04985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     62,     69,0.06973313,0.10027500,0.10027500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     69,     69,0.01932941,0.01027200,0.01027200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     69,     69,0.04664573,0.04980000,0.05044500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     69,     69,0.07077370,0.09976000,0.09976000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      7,     70,0.02266803,0.00968700,0.00968700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      7,     70,0.05880884,0.04816500,0.05089500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      7,     70,0.09103815,0.10069500,0.10069500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     35,     70,0.01996618,0.01005600,0.01005600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     35,     70,0.04920341,0.04959500,0.05022000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     35,     70,0.07519609,0.10088500,0.10088500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     63,     70,0.01819217,0.00989200,0.00989200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     63,     70,0.04541042,0.04977500,0.05082500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     63,     70,0.07016059,0.09907000,0.10135000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     70,     70,0.01845080,0.01013600,0.01013600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     70,     70,0.04511592,0.04991500,0.04991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     70,     70,0.06988518,0.09998000,0.09998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     36,     71,0.01951241,0.00999500,0.00999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     36,     71,0.04808515,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     36,     71,0.07476884,0.09934000,0.09934000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     64,     71,0.01855572,0.01007400,0.01007400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     64,     71,0.04541005,0.04993000,0.04993000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     64,     71,0.06815575,0.09982000,0.09982000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     71,     71,0.01845080,0.01019500,0.01019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     71,     71,0.04507798,0.04881000,0.05058500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     71,     71,0.07077314,0.10078000,0.10078000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     36,     72,0.01951241,0.00985200,0.00985200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     36,     72,0.04823644,0.04963000,0.05040500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     36,     72,0.07476884,0.10037000,0.10037000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     65,     72,0.01855557,0.01007400,0.01007400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     65,     72,0.04529621,0.05007500,0.05007500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     65,     72,0.06883649,0.10078500,0.10078500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     72,     72,0.01761213,0.00976700,0.00976700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     72,     72,0.04523989,0.04962500,0.05141500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     72,     72,0.07006512,0.10075000,0.10075000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     36,     73,0.01951241,0.01020500,0.01020500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     36,     73,0.04874641,0.04853000,0.05074000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     36,     73,0.07349437,0.09914000,0.09914000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     66,     73,0.01855542,0.01027600,0.01027600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     66,     73,0.04502347,0.04995500,0.04995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     66,     73,0.06814785,0.09933500,0.09933500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     73,     73,0.01805243,0.00988500,0.00988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     73,     73,0.04535258,0.04997000,0.04997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     73,     73,0.06936419,0.09963000,0.09963000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     37,     74,0.01951241,0.01019200,0.01019200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     37,     74,0.04728994,0.04868000,0.05082000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     37,     74,0.07265921,0.09957500,0.09957500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     67,     74,0.01772970,0.00969900,0.00969900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     67,     74,0.04451680,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     67,     74,0.06882851,0.10077000,0.10077000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     74,     74,0.01805243,0.01005000,0.01005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     74,     74,0.04489887,0.04991500,0.04991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     74,     74,0.06738211,0.09918500,0.09918500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     38,     75,0.01951241,0.01030300,0.01030300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     38,     75,0.04739661,0.04946500,0.05035000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     38,     75,0.07447569,0.10000500,0.10000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     68,     75,0.01808402,0.01000600,0.01000600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     68,     75,0.04440520,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     68,     75,0.06848396,0.09935000,0.09935000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     75,     75,0.01805243,0.01012300,0.01012300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     75,     75,0.04489851,0.04995500,0.04995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     75,     75,0.06769584,0.09882000,0.10100500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     38,     76,0.01884721,0.01015700,0.01015700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     38,     76,0.04752278,0.04920500,0.05024000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     38,     76,0.07278306,0.09997000,0.09997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     68,     76,0.01781272,0.00992500,0.00992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     68,     76,0.04546282,0.04935500,0.05034500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     68,     76,0.06652703,0.10043500,0.10043500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     76,     76,0.01723187,0.00990600,0.00990600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     76,     76,0.04444935,0.05002500,0.05002500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     76,     76,0.06683949,0.10000000,0.10000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     38,     77,0.01884721,0.00999800,0.00999800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     38,     77,0.04924020,0.04915500,0.05127000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     38,     77,0.07112890,0.09975000,0.09975000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     69,     77,0.01781258,0.00995000,0.00995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     69,     77,0.04500801,0.04988500,0.04988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     69,     77,0.06719150,0.10075000,0.10075000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     77,     77,0.01723187,0.01013900,0.01013900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     77,     77,0.04438578,0.04924000,0.05087000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     77,     77,0.06683896,0.10067500,0.10067500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     39,     78,0.01884721,0.00986000,0.00986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     39,     78,0.04777139,0.05005000,0.05005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     39,     78,0.07290712,0.10043500,0.10043500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     70,     78,0.01781243,0.00999800,0.00999800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     70,     78,0.04425293,0.04864500,0.05041500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     70,     78,0.06706503,0.10057500,0.10057500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     78,     78,0.01684023,0.00974700,0.00974700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     78,     78,0.04438494,0.04957000,0.05054500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     78,     78,0.06683842,0.09955000,0.09955000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,     79,0.01799052,0.00972400,0.00972400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,     79,0.04692099,0.04962000,0.05101000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,     79,0.07381846,0.09918000,0.09918000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     71,     79,0.01701978,0.00971300,0.00971300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     71,     79,0.04417908,0.04924000,0.05112500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     71,     79,0.06706449,0.09937500,0.09937500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     79,     79,0.01726124,0.00990100,0.00990100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     79,     79,0.04453962,0.04980000,0.05032000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     79,     79,0.06683789,0.10067000,0.10067000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      8,     80,0.01967517,0.00973200,0.00973200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      8,     80,0.05370604,0.04917500,0.05125000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      8,     80,0.08418442,0.10044500,0.10044500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,     80,0.01889004,0.01000300,0.01000300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,     80,0.04692099,0.05018000,0.05018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,     80,0.07287476,0.09943500,0.09943500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     72,     80,0.01735990,0.01010100,0.01010100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     72,     80,0.04373711,0.04984500,0.04984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     72,     80,0.06706396,0.10054000,0.10054000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     80,     80,0.01726124,0.00993200,0.00993200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     80,     80,0.04425467,0.04849500,0.05092500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     80,     80,0.06613278,0.09953500,0.09953500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,     81,0.01889004,0.01013100,0.01013100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,     81,0.04692099,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,     81,0.07108152,0.09898000,0.10236000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     73,     81,0.01770682,0.01033000,0.01033000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     73,     81,0.04395536,0.04984500,0.04984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     73,     81,0.06514760,0.10047500,0.10047500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     81,     81,0.01726124,0.01010800,0.01010800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     81,     81,0.04434921,0.04821500,0.05070500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     81,     81,0.06616924,0.09933500,0.09933500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     41,     82,0.01803141,0.00969400,0.00969400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     41,     82,0.04659399,0.04983500,0.04983500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     41,     82,0.07108152,0.09941000,0.09941000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     74,     82,0.01752968,0.01002200,0.01002200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     74,     82,0.04396957,0.04891000,0.05085500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     74,     82,0.06514708,0.10036000,0.10036000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     82,     82,0.01726124,0.01021400,0.01021400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     82,     82,0.04444148,0.04784500,0.05030500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     82,     82,0.06616871,0.10037500,0.10037500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     42,     83,0.01762160,0.00996900,0.00996900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     42,     83,0.04706560,0.04977500,0.05190000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     42,     83,0.07108152,0.10056500,0.10056500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     75,     83,0.01752954,0.01019600,0.01019600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     75,     83,0.04390349,0.04908000,0.05092000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     75,     83,0.06465569,0.09788000,0.10136500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     83,     83,0.01647664,0.01019300,0.01019300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     83,     83,0.04453154,0.04835000,0.05110000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     83,     83,0.06583747,0.09962000,0.09962000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     42,     84,0.01762160,0.01011000,0.01011000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     42,     84,0.04690973,0.04953500,0.05032500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     42,     84,0.07108152,0.09940500,0.09940500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     76,     84,0.01735418,0.01029400,0.01029400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     76,     84,0.04383915,0.04891000,0.05070500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     76,     84,0.06485032,0.09850500,0.10236000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     84,     84,0.01647664,0.01028000,0.01028000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     84,     84,0.04461947,0.04902500,0.05171500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     84,     84,0.06583695,0.10059000,0.10059000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     42,     85,0.01762160,0.00994300,0.00994300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     42,     85,0.04542170,0.04968000,0.05027000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     42,     85,0.07108152,0.09995500,0.09995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     76,     85,0.01735404,0.00983000,0.00983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     76,     85,0.04400313,0.05010500,0.05010500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     76,     85,0.06619216,0.09782500,0.10165000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     85,     85,0.01628940,0.00989200,0.00989200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     85,     85,0.04470536,0.04943000,0.05205000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     85,     85,0.06464597,0.09664500,0.10093500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     43,     86,0.01762160,0.01013500,0.01013500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     43,     86,0.04613142,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     43,     86,0.07093007,0.09967500,0.09967500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     77,     86,0.01735390,0.00998500,0.00998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     77,     86,0.04422271,0.05018500,0.05018500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     77,     86,0.06607712,0.09875000,0.10245000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     86,     86,0.01628940,0.01002100,0.01002100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     86,     86,0.04448157,0.04984500,0.04984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     86,     86,0.06480700,0.10049500,0.10049500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     44,     87,0.01722111,0.01017500,0.01017500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     44,     87,0.04728470,0.05014500,0.05014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     44,     87,0.07093007,0.09920500,0.09920500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     78,     87,0.01713437,0.01012800,0.01012800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     78,     87,0.04422236,0.04986000,0.04986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     78,     87,0.06591147,0.10004500,0.10004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     87,     87,0.01628940,0.00980800,0.00980800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     87,     87,0.04448121,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     87,     87,0.06483774,0.09711500,0.10152500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     44,     88,0.01722111,0.00998400,0.00998400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     44,     88,0.04600855,0.05011500,0.05011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     44,     88,0.06931802,0.10007500,0.10007500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     79,     88,0.01696296,0.00971900,0.00971900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     79,     88,0.04331082,0.05002500,0.05002500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     79,     88,0.06574623,0.10062500,0.10062500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     88,     88,0.01649302,0.01009700,0.01009700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     88,     88,0.04289690,0.04915500,0.05035000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     88,     88,0.06493035,0.09770500,0.10222000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     44,     89,0.01722111,0.01017700,0.01017700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     44,     89,0.04526829,0.04971000,0.05024000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     44,     89,0.07018450,0.09911500,0.09911500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     80,     89,0.01696283,0.01004600,0.01004600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     80,     89,0.04363645,0.04954500,0.05031500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     80,     89,0.06508850,0.09951000,0.09951000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     89,     89,0.01664267,0.01031400,0.01031400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     89,     89,0.04305065,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     89,     89,0.06502089,0.09660000,0.10112000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,      9,     90,0.01833369,0.01007800,0.01007800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,      9,     90,0.05220316,0.04891500,0.05121000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,      9,     90,0.07701402,0.09286500,0.10198500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     45,     90,0.01722111,0.01019500,0.01019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     45,     90,0.04473174,0.04978500,0.05060500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     45,     90,0.06938695,0.10045500,0.10045500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     81,     90,0.01696269,0.01011200,0.01011200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     81,     90,0.04347253,0.04991500,0.04991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     81,     90,0.06541329,0.09912000,0.09912000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     90,     90,0.01626443,0.00985600,0.00985600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     90,     90,0.04319252,0.04948500,0.05066500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     90,     90,0.06462508,0.09915000,0.09915000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     46,     91,0.01722111,0.01009800,0.01009800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     46,     91,0.04441404,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     46,     91,0.06820421,0.09951000,0.09951000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     82,     91,0.01696256,0.01002900,0.01002900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     82,     91,0.04231684,0.05002500,0.05002500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     82,     91,0.06541277,0.10083000,0.10083000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     91,     91,0.01626443,0.00972100,0.00972100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     91,     91,0.04305031,0.04994500,0.04994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     91,     91,0.06502037,0.09946000,0.09946000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     46,     92,0.01682972,0.01023900,0.01023900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     46,     92,0.04495392,0.04979000,0.05029500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     46,     92,0.06863049,0.09986500,0.09986500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     83,     92,0.01696242,0.00991400,0.00991400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     83,     92,0.04218431,0.05013000,0.05013000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     83,     92,0.06508531,0.09963000,0.09963000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     92,     92,0.01626443,0.01008800,0.01008800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     92,     92,0.04304997,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     92,     92,0.06436991,0.10005000,0.10005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     46,     93,0.01682972,0.00985100,0.00985100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     46,     93,0.04509440,0.04984500,0.04984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     46,     93,0.06863049,0.09990500,0.09990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     84,     93,0.01730140,0.01015600,0.01015600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     84,     93,0.04214256,0.04937000,0.05063000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     84,     93,0.06514240,0.09733000,0.10113000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     93,     93,0.01626443,0.00996400,0.00996400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     93,     93,0.04304962,0.04988500,0.04988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     93,     93,0.06469112,0.10078000,0.10078000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     47,     94,0.01680582,0.01033000,0.01033000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     47,     94,0.06863049,0.10084500,0.10084500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     85,     94,0.01653148,0.00990500,0.00990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     85,     94,0.04225934,0.04871500,0.05051000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     85,     94,0.06525523,0.09844500,0.10224500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     94,     94,0.01626443,0.00983100,0.00983100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     94,     94,0.04278569,0.04977500,0.05031500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     94,     94,0.06404395,0.09934500,0.09934500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     48,     95,0.01701589,0.01026800,0.01026800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     48,     95,0.04447555,0.04982000,0.04982000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     48,     95,0.06732963,0.09914000,0.09914000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     86,     95,0.01686185,0.01029100,0.01029100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     86,     95,0.04241137,0.04885500,0.05057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     86,     95,0.06516335,0.09804500,0.10172500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     95,     95,0.01626443,0.00989300,0.00989300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     95,     95,0.04235767,0.05012500,0.05012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     95,     95,0.06412346,0.10058000,0.10058000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     48,     96,0.01662916,0.00993100,0.00993100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     48,     96,0.04447555,0.05010500,0.05010500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     48,     96,0.06796085,0.10041000,0.10041000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     86,     96,0.01686171,0.01017300,0.01017300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     86,     96,0.04188111,0.04997500,0.04997500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     86,     96,0.06426719,0.10035000,0.10035000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     96,     96,0.01626443,0.00995600,0.00995600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     96,     96,0.04210835,0.04958500,0.05026500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     96,     96,0.06476392,0.10026000,0.10026000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     48,     97,0.01662916,0.00981000,0.00981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     48,     97,0.04397015,0.04986000,0.04986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     48,     97,0.06817323,0.10056500,0.10056500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     87,     97,0.01676668,0.01016700,0.01016700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     87,     97,0.04209009,0.04990000,0.04990000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     87,     97,0.06441981,0.09789000,0.10159000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     97,     97,0.01626443,0.01011400,0.01011400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     97,     97,0.04168710,0.05017500,0.05017500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     97,     97,0.06476340,0.10056000,0.10056000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     49,     98,0.01662916,0.01015600,0.01015600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     49,     98,0.04433281,0.04965000,0.05073500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     49,     98,0.06662383,0.09944500,0.09944500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     88,     98,0.01676668,0.01026000,0.01026000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     88,     98,0.04230012,0.04986000,0.04986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     88,     98,0.06461986,0.09815500,0.10187000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     98,     98,0.01570996,0.01019000,0.01019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     98,     98,0.04179095,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     98,     98,0.06468196,0.09996000,0.09996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,     99,0.01662916,0.00983000,0.00983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,     99,0.04400220,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,     99,0.06662383,0.09991500,0.09991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     89,     99,0.01676668,0.01027200,0.01027200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     89,     99,0.04229978,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     89,     99,0.06481602,0.09897500,0.10289500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     99,     99,0.01570996,0.01017100,0.01017100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     99,     99,0.04199948,0.05015000,0.05015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     99,     99,0.06468145,0.09941000,0.09941000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     10,    100,0.01708366,0.01008000,0.01008000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     10,    100,0.04871801,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     10,    100,0.07701402,0.09919500,0.09919500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,    100,0.01662916,0.00988400,0.00988400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,    100,0.04400220,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,    100,0.06662383,0.09935500,0.09935500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     90,    100,0.01600456,0.01011600,0.01011600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     90,    100,0.04229944,0.05018000,0.05018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     90,    100,0.06481550,0.09951500,0.09951500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    100,    100,0.01570996,0.01015200,0.01015200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    100,    100,0.04168428,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    100,    100,0.06500421,0.09965000,0.09965000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,    101,0.01662916,0.01015700,0.01015700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,    101,0.04400220,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,    101,0.06681667,0.09790000,0.10114000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     91,    101,0.01600456,0.01002500,0.01002500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     91,    101,0.04219235,0.04866500,0.05047500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     91,    101,0.06426553,0.10049000,0.10049000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    101,    101,0.01570996,0.00976200,0.00976200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    101,    101,0.04085274,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    101,    101,0.06364444,0.10023500,0.10023500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     51,    102,0.01668113,0.00990800,0.00990800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     51,    102,0.04275214,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     51,    102,0.06548792,0.10040500,0.10040500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     92,    102,0.01600456,0.01003300,0.01003300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     92,    102,0.04233445,0.04960500,0.05145000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     92,    102,0.06353524,0.09950500,0.09950500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    102,    102,0.01570996,0.00998600,0.00998600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    102,    102,0.04074258,0.04979000,0.05021500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    102,    102,0.06292120,0.09941000,0.09941000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     52,    103,0.01668113,0.00983300,0.00983300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     52,    103,0.04359687,0.04948500,0.05059500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     52,    103,0.06548792,0.09930500,0.09930500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     93,    103,0.01600456,0.01019100,0.01019100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     93,    103,0.04137230,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     93,    103,0.06353524,0.10032000,0.10032000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    103,    103,0.01590633,0.01011400,0.01011400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    103,    103,0.04074258,0.05010000,0.05010000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    103,    103,0.06149118,0.10033500,0.10033500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     52,    104,0.01668113,0.00971300,0.00971300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     52,    104,0.04386935,0.05000000,0.05000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     52,    104,0.06630652,0.10029000,0.10029000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     94,    104,0.01600456,0.00998900,0.00998900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     94,    104,0.04214803,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     94,    104,0.06393233,0.10039000,0.10039000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    104,    104,0.01577077,0.01022200,0.01022200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    104,    104,0.03889065,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    104,    104,0.06149118,0.10004000,0.10004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     52,    105,0.01668113,0.00996700,0.00996700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     52,    105,0.04268196,0.04972500,0.05037000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     52,    105,0.06630652,0.09916500,0.09916500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     94,    105,0.01564082,0.00998500,0.00998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     94,    105,0.04171921,0.04947500,0.05129500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     94,    105,0.06393233,0.10082500,0.10082500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    105,    105,0.01577077,0.01014800,0.01014800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    105,    105,0.03986291,0.05016000,0.05016000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    105,    105,0.06225982,0.09967000,0.09967000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     53,    106,0.01668113,0.00994700,0.00994700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     53,    106,0.04286818,0.04962000,0.05096000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     53,    106,0.06555304,0.09920000,0.09920000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     95,    106,0.01564082,0.01005100,0.01005100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     95,    106,0.04118587,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     95,    106,0.06320583,0.09921000,0.09921000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    106,    106,0.01596790,0.01012500,0.01012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    106,    106,0.03986291,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    106,    106,0.06225982,0.10064500,0.10064500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     54,    107,0.01668113,0.01020600,0.01020600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     54,    107,0.04330694,0.04966500,0.05028000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     54,    107,0.06462189,0.10048500,0.10048500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     96,    107,0.01564082,0.00999600,0.00999600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     96,    107,0.04095186,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     96,    107,0.06266714,0.09933000,0.09933000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    107,    107,0.01560499,0.00976100,0.00976100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    107,    107,0.03963642,0.04996000,0.04996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    107,    107,0.06155232,0.10069000,0.10069000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     54,    108,0.01668113,0.00982900,0.00982900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     54,    108,0.04297797,0.04959500,0.05108500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     54,    108,0.06592052,0.09862000,0.10201500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     97,    108,0.01564082,0.01002100,0.01002100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     97,    108,0.04114382,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     97,    108,0.06345048,0.09984500,0.09984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    108,    108,0.01560499,0.00990400,0.00990400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    108,    108,0.04013188,0.05005000,0.05005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    108,    108,0.06155232,0.09984500,0.09984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     54,    109,0.01630201,0.00984300,0.00984300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     54,    109,0.04202967,0.04931500,0.05075000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     54,    109,0.06442233,0.09915500,0.09915500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     98,    109,0.01564082,0.01014500,0.01014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     98,    109,0.04067628,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     98,    109,0.06345048,0.09963500,0.09963500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    109,    109,0.01560499,0.00978700,0.00978700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    109,    109,0.03911017,0.04974000,0.05044000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    109,    109,0.06155232,0.09921500,0.09921500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     55,    110,0.01670956,0.00993800,0.00993800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     55,    110,0.04272639,0.05003500,0.05003500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     55,    110,0.06581676,0.09935000,0.09935000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     99,    110,0.01564082,0.01006000,0.01006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     99,    110,0.04080339,0.04989500,0.04989500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     99,    110,0.06345048,0.10032500,0.10032500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    110,    110,0.01560499,0.00982400,0.00982400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    110,    110,0.03935460,0.05012500,0.05012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    110,    110,0.06155232,0.10017000,0.10017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     56,    111,0.01670956,0.01014700,0.01014700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     56,    111,0.04339399,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     56,    111,0.06469489,0.09979000,0.09979000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    100,    111,0.01564082,0.01027600,0.01027600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    100,    111,0.04010788,0.05005500,0.05005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    100,    111,0.06200842,0.09913500,0.09913500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    111,    111,0.01560499,0.01001900,0.01001900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    111,    111,0.03890739,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    111,    111,0.06155232,0.09939500,0.09939500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     56,    112,0.01670956,0.01021200,0.01021200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     56,    112,0.04231872,0.04972000,0.05027500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     56,    112,0.06469489,0.09951500,0.09951500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    101,    112,0.01564082,0.01032700,0.01032700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    101,    112,0.04098524,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    101,    112,0.06355863,0.10069000,0.10069000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    112,    112,0.01560499,0.00999700,0.00999700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    112,    112,0.03890739,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    112,    112,0.06015340,0.10048000,0.10048000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     56,    113,0.01632980,0.00997700,0.00997700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     56,    113,0.04201816,0.04990000,0.04990000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     56,    113,0.06395972,0.09944500,0.09944500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    102,    113,0.01546308,0.00995600,0.00995600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    102,    113,0.04098524,0.05011500,0.05011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    102,    113,0.06211412,0.10004000,0.10004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    113,    113,0.01560499,0.01024700,0.01024700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    113,    113,0.03813148,0.04952000,0.05020000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    113,    113,0.06015340,0.10086500,0.10086500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     57,    114,0.01632980,0.00982500,0.00982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     57,    114,0.04228077,0.04995500,0.04995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     57,    114,0.06395972,0.09983500,0.09983500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    103,    114,0.01546308,0.01009400,0.01009400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    103,    114,0.04063594,0.04993500,0.04993500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    103,    114,0.06211412,0.10011500,0.10011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    114,    114,0.01560499,0.01018400,0.01018400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    114,    114,0.03848897,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    114,    114,0.05981162,0.10049500,0.10049500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     58,    115,0.01632980,0.00984000,0.00984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     58,    115,0.04229729,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     58,    115,0.06395972,0.10048000,0.10048000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    104,    115,0.01546308,0.00999000,0.00999000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    104,    115,0.03971239,0.04991500,0.04991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    104,    115,0.06105536,0.10066000,0.10066000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    115,    115,0.01560499,0.01023400,0.01023400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    115,    115,0.03834853,0.04944000,0.05024500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    115,    115,0.05947178,0.09982500,0.09982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     58,    116,0.01632980,0.00990100,0.00990100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     58,    116,0.04109566,0.04990500,0.04990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     58,    116,0.06323290,0.10001000,0.10001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    104,    116,0.01562350,0.01023900,0.01023900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    104,    116,0.04058110,0.04994500,0.04994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    104,    116,0.06239094,0.10033500,0.10033500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    116,    116,0.01560499,0.01031600,0.01031600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    116,    116,0.03845434,0.04953000,0.05023500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    116,    116,0.06021518,0.10079000,0.10079000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     58,    117,0.01632980,0.01013900,0.01013900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     58,    117,0.04160935,0.05018500,0.05018500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     58,    117,0.06323290,0.10040500,0.10040500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    105,    117,0.01526842,0.00967400,0.00967400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    105,    117,0.03919765,0.04988000,0.04988000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    105,    117,0.06168195,0.09955500,0.09955500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    117,    117,0.01560499,0.01024300,0.01024300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    117,    117,0.03845434,0.05003000,0.05003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    117,    117,0.05987305,0.09945000,0.09945000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     59,    118,0.01632980,0.01002100,0.01002100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     59,    118,0.04160935,0.04999000,0.04999000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     59,    118,0.06251435,0.09994500,0.09994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    106,    118,0.01565013,0.01013200,0.01013200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    106,    118,0.04017759,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    106,    118,0.06206747,0.09926500,0.09926500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    118,    118,0.01542766,0.00980400,0.00980400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    118,    118,0.03839971,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    118,    118,0.05987305,0.09973500,0.09973500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     60,    119,0.01632980,0.01001900,0.01001900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     60,    119,0.06251435,0.09937500,0.09937500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    107,    119,0.01529444,0.00975000,0.00975000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    107,    119,0.03903619,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    107,    119,0.06136215,0.09938000,0.09938000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    119,    119,0.01542766,0.00990900,0.00990900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    119,    119,0.03818153,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    119,    119,0.05987305,0.10012500,0.10012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     60,    120,0.01632980,0.01022700,0.01022700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     60,    120,0.04085274,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     60,    120,0.06209213,0.10057000,0.10057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    108,    120,0.01529444,0.00978800,0.00978800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    108,    120,0.03881439,0.05019000,0.05019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    108,    120,0.06136215,0.10008500,0.10008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    120,    120,0.01542766,0.00976300,0.00976300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    120,    120,0.03818153,0.04983500,0.04983500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    120,    120,0.05987305,0.10049500,0.10049500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     60,    121,0.01558754,0.00996100,0.00996100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     60,    121,0.04091657,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     60,    121,0.06209213,0.09922000,0.09922000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    109,    121,0.01529444,0.00986800,0.00986800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    109,    121,0.03859385,0.04990000,0.04990000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    109,    121,0.05996756,0.09913500,0.09913500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    121,    121,0.01542766,0.00983900,0.00983900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    121,    121,0.03818153,0.04997500,0.04997500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    121,    121,0.05851230,0.10019000,0.10019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     61,    122,0.01558754,0.00982900,0.00982900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     61,    122,0.04021913,0.04986500,0.04986500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     61,    122,0.06209213,0.10024500,0.10024500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    110,    122,0.01529444,0.00984600,0.00984600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    110,    122,0.03862400,0.05005500,0.05005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    110,    122,0.06109195,0.10076000,0.10076000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    122,    122,0.01542766,0.01000400,0.01000400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    122,    122,0.03687989,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    122,    122,0.05851230,0.09989500,0.09989500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     62,    123,0.01558754,0.00977500,0.00977500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     62,    123,0.04103608,0.04988000,0.04988000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     62,    123,0.06138654,0.10079000,0.10079000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    111,    123,0.01529444,0.00993200,0.00993200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    111,    123,0.03855885,0.05009500,0.05009500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    111,    123,0.06039773,0.09996000,0.09996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    123,    123,0.01542766,0.00997600,0.00997600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    123,    123,0.03711039,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    123,    123,0.05851230,0.09935500,0.09935500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     62,    124,0.01558754,0.01005400,0.01005400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     62,    124,0.04010345,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     62,    124,0.06177021,0.09988000,0.09988000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    112,    124,0.01529444,0.01022400,0.01022400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    112,    124,0.03879985,0.04998000,0.04998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    112,    124,0.06115270,0.10024500,0.10024500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    124,    124,0.01542766,0.01018300,0.01018300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    124,    124,0.03711039,0.04994500,0.04994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    124,    124,0.05851230,0.09965500,0.09965500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     62,    125,0.01558754,0.00988500,0.00988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     62,    125,0.04064737,0.04891000,0.05046000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     62,    125,0.06106827,0.10020000,0.10020000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    112,    125,0.01529444,0.01005700,0.01005700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    112,    125,0.03890292,0.04975500,0.05024000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    112,    125,0.05976286,0.10035500,0.10035500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    125,    125,0.01507704,0.00996800,0.00996800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    125,    125,0.03711039,0.05000000,0.05000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    125,    125,0.05851230,0.09961000,0.09961000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     63,    126,0.01558754,0.00995100,0.00995100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     63,    126,0.04030095,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     63,    126,0.06106827,0.09940500,0.09940500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    113,    126,0.01529444,0.01001600,0.01001600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    113,    126,0.03846084,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    113,    126,0.05976286,0.09923000,0.09923000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    126,    126,0.01507704,0.00991600,0.00991600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    126,    126,0.03634604,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    126,    126,0.05851230,0.10033500,0.10033500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     64,    127,0.01558754,0.01024300,0.01024300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     64,    127,0.03938502,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     64,    127,0.06106827,0.10025000,0.10025000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    114,    127,0.01529444,0.01017100,0.01017100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    114,    127,0.03846084,0.05011500,0.05011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    114,    127,0.05908374,0.10000500,0.10000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    127,    127,0.01507704,0.00994800,0.00994800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    127,    127,0.03634604,0.04985500,0.04985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    127,    127,0.05784738,0.09971500,0.09971500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     64,    128,0.01558754,0.01011600,0.01011600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     64,    128,0.04036964,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     64,    128,0.06106827,0.09988000,0.09988000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    115,    128,0.01529444,0.01029700,0.01029700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    115,    128,0.03846084,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    115,    128,0.05908374,0.09949500,0.09949500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    128,    128,0.01507704,0.01016000,0.01016000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    128,    128,0.03634604,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    128,    128,0.05820893,0.09978000,0.09978000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     64,    129,0.01523327,0.00985800,0.00985800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     64,    129,0.03985355,0.05011500,0.05011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     64,    129,0.06106827,0.10057000,0.10057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    116,    129,0.01529444,0.01027100,0.01027100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    116,    129,0.03846084,0.05019000,0.05019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    116,    129,0.05982229,0.10040500,0.10040500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    129,    129,0.01507704,0.00988500,0.00988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    129,    129,0.03625558,0.04796500,0.05072000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    129,    129,0.05820893,0.09998000,0.09998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     65,    130,0.01523327,0.01002300,0.01002300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     65,    130,0.04004385,0.04965000,0.05113000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     65,    130,0.06106827,0.10037000,0.10037000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    117,    130,0.01494684,0.01018300,0.01018300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    117,    130,0.03824231,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    117,    130,0.05982229,0.10055500,0.10055500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    130,    130,0.01507704,0.01008800,0.01008800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    130,    130,0.03627694,0.04809500,0.05089000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    130,    130,0.05672063,0.10011500,0.10011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     66,    131,0.01523327,0.00986900,0.00986900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     66,    131,0.03936129,0.05012000,0.05012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     66,    131,0.06041240,0.09875000,0.10255500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    118,    131,0.01494684,0.00971100,0.00971100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    118,    131,0.03824231,0.04992000,0.04992000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    118,    131,0.05914249,0.09994500,0.09994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    131,    131,0.01507704,0.01004800,0.01004800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    131,    131,0.03629820,0.05015000,0.05015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    131,    131,0.05707514,0.10014500,0.10014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     66,    132,0.01523327,0.00997200,0.00997200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     66,    132,0.04009931,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     66,    132,0.06041240,0.10082500,0.10082500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    119,    132,0.01494684,0.00995000,0.00995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    119,    132,0.03824231,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    119,    132,0.05914249,0.09955500,0.09955500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    132,    132,0.01507704,0.01019900,0.01019900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    132,    132,0.03631869,0.04853500,0.05095500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    132,    132,0.05707514,0.10082500,0.10082500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     66,    133,0.01523327,0.00996000,0.00996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     66,    133,0.04009931,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     66,    133,0.06116756,0.10065500,0.10065500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    120,    133,0.01494684,0.01003200,0.01003200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    120,    133,0.03813367,0.04993000,0.04993000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    120,    133,0.05951213,0.09969000,0.09969000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    133,    133,0.01507704,0.01025000,0.01025000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    133,    133,0.03637543,0.04981000,0.04981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    133,    133,0.05707514,0.10010000,0.10010000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     67,    134,0.01523327,0.01000000,0.01000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     67,    134,0.04019329,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     67,    134,0.06012493,0.10007000,0.10007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    121,    134,0.01494684,0.01016800,0.01016800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    121,    134,0.03791700,0.04990500,0.04990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    121,    134,0.05951213,0.10051000,0.10051000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    134,    134,0.01473438,0.01006300,0.01006300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    134,    134,0.03635920,0.04746000,0.05019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    134,    134,0.05707514,0.10075000,0.10075000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     68,    135,0.01488706,0.00997400,0.00997400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     68,    135,0.03905144,0.05007000,0.05007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     68,    135,0.06047722,0.09929500,0.09929500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    122,    135,0.01494684,0.01013600,0.01013600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    122,    135,0.03791700,0.05001500,0.05001500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    122,    135,0.05951213,0.10061500,0.10061500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    135,    135,0.01473438,0.00991300,0.00991300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    135,    135,0.03637901,0.04755000,0.05032500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    135,    135,0.05707514,0.09931000,0.09931000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     68,    136,0.01488706,0.00980300,0.00980300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     68,    136,0.03978365,0.04997000,0.04997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     68,    136,0.05978998,0.10031500,0.10031500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    122,    136,0.01494684,0.00987900,0.00987900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    122,    136,0.03770156,0.04999500,0.04999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    122,    136,0.05849772,0.10060500,0.10060500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    136,    136,0.01473438,0.01003200,0.01003200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    136,    136,0.03654907,0.04950500,0.05043000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    136,    136,0.05707514,0.10011000,0.10011000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     68,    137,0.01488706,0.00993400,0.00993400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     68,    137,0.03887948,0.05013000,0.05013000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     68,    137,0.05911055,0.09965500,0.09965500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    123,    137,0.01494684,0.00988200,0.00988200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    123,    137,0.03760784,0.04997500,0.04997500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    123,    137,0.05849772,0.10042000,0.10042000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    137,    137,0.01473438,0.01015600,0.01015600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    137,    137,0.03641776,0.04796000,0.05073500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    137,    137,0.05577798,0.10051500,0.10051500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     69,    138,0.01488706,0.01001700,0.01001700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     69,    138,0.03904654,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     69,    138,0.05974481,0.09771500,0.10152000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    124,    138,0.01494684,0.00993600,0.00993600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    124,    138,0.03766646,0.04979500,0.05021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    124,    138,0.05849772,0.10001500,0.10001500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    138,    138,0.01473438,0.01024900,0.01024900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    138,    138,0.03643672,0.04912000,0.05189000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    138,    138,0.05514413,0.10042000,0.10042000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     70,    139,0.01488706,0.01023000,0.01023000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     70,    139,0.03967009,0.04980500,0.05135500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     70,    139,0.06056176,0.09877000,0.10260500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    125,    139,0.01494684,0.01000000,0.01000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    125,    139,0.03749017,0.04962500,0.05028500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    125,    139,0.05716822,0.09999000,0.09999000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    139,    139,0.01473438,0.01027800,0.01027800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    139,    139,0.03645540,0.04833500,0.05102500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    139,    139,0.05514413,0.09986000,0.09986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     70,    140,0.01488706,0.01008600,0.01008600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     70,    140,0.03831770,0.04994500,0.04994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     70,    140,0.05979128,0.09785000,0.10148000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    126,    140,0.01494684,0.00984600,0.00984600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    126,    140,0.03743087,0.04963500,0.05032500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    126,    140,0.05788283,0.10047500,0.10047500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    140,    140,0.01473438,0.01021500,0.01021500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    140,    140,0.03647382,0.04794500,0.05050500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    140,    140,0.05652274,0.09962500,0.09962500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     70,    141,0.01488706,0.01025000,0.01025000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     70,    141,0.03880415,0.04982000,0.04982000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     70,    141,0.05903413,0.09744000,0.10106500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    127,    141,0.01494684,0.01014400,0.01014400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    127,    141,0.03754784,0.05010000,0.05010000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    127,    141,0.05788283,0.10061000,0.10061000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    141,    141,0.01406463,0.00972800,0.00972800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    141,    141,0.03649198,0.04843000,0.05103000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    141,    141,0.05555928,0.09927000,0.09927000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     71,    142,0.01488706,0.01012400,0.01012400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     71,    142,0.03819784,0.05002000,0.05002000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     71,    142,0.05977206,0.09946000,0.09946000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    128,    142,0.01494684,0.01023300,0.01023300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    128,    142,0.03731519,0.04956000,0.05024000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    128,    142,0.05788283,0.09916000,0.09916000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    142,    142,0.01441625,0.01018300,0.01018300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    142,    142,0.03650989,0.04879500,0.05152500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    142,    142,0.05555928,0.10057000,0.10057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     72,    143,0.01488706,0.01014300,0.01014300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     72,    143,0.03754674,0.04985500,0.04985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     72,    143,0.05977206,0.10019000,0.10019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    129,    143,0.01494684,0.01007900,0.01007900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    129,    143,0.03754841,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    129,    143,0.05788283,0.09967000,0.09967000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    143,    143,0.01441625,0.01008600,0.01008600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    143,    143,0.03652754,0.04860000,0.05126000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    143,    143,0.05492793,0.10020000,0.10020000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     72,    144,0.01488706,0.01024000,0.01024000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     72,    144,0.03825074,0.04983500,0.04983500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     72,    144,0.05977206,0.09964500,0.09964500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    130,    144,0.01426744,0.00966800,0.00966800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    130,    144,0.03712173,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    130,    144,0.05788283,0.10082500,0.10082500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    144,    144,0.01441625,0.01025200,0.01025200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    144,    144,0.03654496,0.04766000,0.05041000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    144,    144,0.05492793,0.10047500,0.10047500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     72,    145,0.01488706,0.00985500,0.00985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     72,    145,0.03872887,0.05017000,0.05017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     72,    145,0.05914315,0.09799500,0.10159500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    130,    145,0.01462413,0.01014400,0.01014400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    130,    145,0.03691081,0.05015000,0.05015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    130,    145,0.05673175,0.09965500,0.09965500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    145,    145,0.01441625,0.01025200,0.01025200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    145,    145,0.03656213,0.04856000,0.05152000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    145,    145,0.05492793,0.10030500,0.10030500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     73,    146,0.01454872,0.01019600,0.01019600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     73,    146,0.03839880,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     73,    146,0.05914315,0.10032000,0.10032000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    131,    146,0.01462413,0.01005000,0.01005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    131,    146,0.03670109,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    131,    146,0.05673175,0.10020000,0.10020000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    146,    146,0.01441625,0.01028100,0.01028100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    146,    146,0.03657907,0.04833000,0.05115500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    146,    146,0.05527123,0.10005000,0.10005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     74,    147,0.01454872,0.01008600,0.01008600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     74,    147,0.03752610,0.04992500,0.04992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     74,    147,0.05914315,0.09997000,0.09997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    132,    147,0.01462413,0.01001200,0.01001200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    132,    147,0.03715985,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    132,    147,0.05744089,0.10035500,0.10035500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    147,    147,0.01441625,0.01010900,0.01010900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    147,    147,0.03659578,0.04819500,0.05099000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    147,    147,0.05527123,0.10049000,0.10049000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     74,    148,0.01454872,0.00989200,0.00989200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     74,    148,0.03828159,0.04961000,0.05019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     74,    148,0.05914315,0.09929000,0.09929000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    133,    148,0.01462413,0.00995400,0.00995400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    133,    148,0.03694872,0.04995500,0.04995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    133,    148,0.05678816,0.10019500,0.10019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    148,    148,0.01441625,0.01013100,0.01013100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    148,    148,0.03661226,0.04787500,0.05061000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    148,    148,0.05527123,0.09988500,0.09988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     74,    149,0.01454872,0.00986700,0.00986700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     74,    149,0.03887974,0.05016500,0.05016500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     74,    149,0.05914315,0.10038000,0.10038000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    134,    149,0.01462413,0.01004600,0.01004600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    134,    149,0.03717965,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    134,    149,0.05678816,0.09964500,0.09964500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    149,    149,0.01441625,0.01031700,0.01031700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    149,    149,0.03662852,0.04831000,0.05100000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    149,    149,0.05464314,0.10055000,0.10055000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     75,    150,0.01454872,0.00994600,0.00994600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     75,    150,0.03832747,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     75,    150,0.05914315,0.10019000,0.10019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    135,    150,0.01462413,0.01014000,0.01014000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    135,    150,0.03644028,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    135,    150,0.05614284,0.10010500,0.10010500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    150,    150,0.01397550,0.00983300,0.00983300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    150,    150,0.03664457,0.04907000,0.05171500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    150,    150,0.05532618,0.10084500,0.10084500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     76,    151,0.01454872,0.01007200,0.01007200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     76,    151,0.03764694,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     76,    151,0.05847107,0.09996500,0.09996500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    136,    151,0.01462413,0.01026900,0.01026900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    136,    151,0.03644028,0.04981500,0.04981500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    136,    151,0.05614284,0.09956000,0.09956000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    151,    151,0.01397550,0.00980500,0.00980500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    151,    151,0.03666041,0.04930000,0.05206500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    151,    151,0.05467713,0.09627000,0.10116500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     76,    152,0.01454872,0.01007300,0.01007300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     76,    152,0.03836753,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     76,    152,0.05847107,0.09980500,0.09980500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    137,    152,0.01462413,0.00996000,0.00996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    137,    152,0.03649722,0.04986500,0.04986500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    137,    152,0.05614284,0.10069000,0.10069000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    152,    152,0.01397550,0.00991400,0.00991400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    152,    152,0.03666041,0.04985500,0.04985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    152,    152,0.05469530,0.09674500,0.10199000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     76,    153,0.01454872,0.00986600,0.00986600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     76,    153,0.03749554,0.05000500,0.05000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     76,    153,0.05847107,0.09966500,0.09966500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    138,    153,0.01395939,0.00983800,0.00983800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    138,    153,0.03649722,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    138,    153,0.05486686,0.09919000,0.09919000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    153,    153,0.01397550,0.00982200,0.00982200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    153,    153,0.03669146,0.04924000,0.05204000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    153,    153,0.05471324,0.09597500,0.10102000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     77,    154,0.01454872,0.00995400,0.00995400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     77,    154,0.03819858,0.04996000,0.04996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     77,    154,0.05847107,0.10080500,0.10080500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    139,    154,0.01430838,0.01008700,0.01008700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    139,    154,0.03628985,0.04993000,0.04993000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    139,    154,0.05486686,0.10043000,0.10043000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    154,    154,0.01397550,0.00979700,0.00979700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    154,    154,0.03669146,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    154,    154,0.05473094,0.09669000,0.10204000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     78,    155,0.01454872,0.01032100,0.01032100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     78,    155,0.03776451,0.05014500,0.05014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     78,    155,0.05780662,0.09979000,0.09979000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    140,    155,0.01430838,0.01016000,0.01016000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    140,    155,0.03579772,0.04936500,0.05034000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    140,    155,0.05424338,0.10000500,0.10000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    155,    155,0.01397550,0.00981800,0.00981800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    155,    155,0.03606604,0.05005000,0.05005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    155,    155,0.05473094,0.09960000,0.09960000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     78,    156,0.01454872,0.00970200,0.00970200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     78,    156,0.03765722,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     78,    156,0.05714973,0.09933000,0.09933000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    140,    156,0.01430838,0.00997600,0.00997600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    140,    156,0.03624519,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    140,    156,0.05627750,0.09966000,0.09966000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    156,    156,0.01397550,0.01016100,0.01016100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    156,    156,0.03651687,0.05000000,0.05000000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    156,    156,0.05476567,0.09741000,0.10253500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     78,    157,0.01454872,0.01004700,0.01004700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     78,    157,0.03812794,0.04993500,0.04993500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     78,    157,0.05857847,0.10033000,0.10033000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    141,    157,0.01430838,0.01014800,0.01014800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    141,    157,0.03603925,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    141,    157,0.05499847,0.09975000,0.09975000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    157,    157,0.01397550,0.00997700,0.00997700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    157,    157,0.03651687,0.05005500,0.05005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    157,    157,0.05478270,0.09626500,0.10127500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     79,    158,0.01454872,0.00983900,0.00983900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     79,    158,0.03791130,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     79,    158,0.05791281,0.09985500,0.09985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    142,    158,0.01430838,0.01018400,0.01018400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    142,    158,0.03603925,0.04992500,0.04992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    142,    158,0.05499847,0.10010500,0.10010500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    158,    158,0.01397550,0.01008300,0.01008300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    158,    158,0.03651687,0.05014500,0.05014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    158,    158,0.05479951,0.09699000,0.10213500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     80,    159,0.01454872,0.01028300,0.01028300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     80,    159,0.03737279,0.04988000,0.04988000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     80,    159,0.05659661,0.09965000,0.09965000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    143,    159,0.01430838,0.01018200,0.01018200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    143,    159,0.03562971,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    143,    159,0.05499847,0.10074500,0.10074500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    159,    159,0.01397550,0.01031100,0.01031100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    159,    159,0.03627578,0.04960000,0.05051000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    159,    159,0.05481612,0.09766000,0.10285500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     80,    160,0.01454872,0.00991300,0.00991300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     80,    160,0.03748958,0.04981500,0.04981500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     80,    160,0.05801152,0.10007500,0.10007500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    144,    160,0.01430838,0.01022800,0.01022800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    144,    160,0.03585240,0.05001500,0.05001500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    144,    160,0.05499847,0.10044000,0.10044000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    160,    160,0.01397550,0.01027600,0.01027600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    160,    160,0.03663003,0.05002500,0.05002500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    160,    160,0.05483251,0.09753500,0.10269000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     80,    161,0.01421807,0.00987400,0.00987400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     80,    161,0.03690380,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     80,    161,0.05735230,0.10060500,0.10060500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    145,    161,0.01430838,0.01017300,0.01017300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    145,    161,0.03596444,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    145,    161,0.05499847,0.10074000,0.10074000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    161,    161,0.01397550,0.01011000,0.01011000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    161,    161,0.03635626,0.04943000,0.05029500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    161,    161,0.05484871,0.09787500,0.10303000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     81,    162,0.01421807,0.00984500,0.00984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     81,    162,0.03637960,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     81,    162,0.05670057,0.09939500,0.09939500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    146,    162,0.01430838,0.00998800,0.00998800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    146,    162,0.03618921,0.05003000,0.05003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    146,    162,0.05499847,0.10037500,0.10037500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    162,    162,0.01397550,0.00993900,0.00993900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    162,    162,0.03635626,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    162,    162,0.05486470,0.09876000,0.10417000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     82,    163,0.01421807,0.00982200,0.00982200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     82,    163,0.03637960,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     82,    163,0.05605624,0.09952000,0.09952000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    147,    163,0.01430838,0.01016400,0.01016400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    147,    163,0.03577797,0.05008000,0.05008000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    147,    163,0.05437349,0.10027500,0.10027500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    163,    163,0.01397550,0.00992300,0.00992300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    163,    163,0.03552998,0.04981000,0.04981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    163,    163,0.05486470,0.09913500,0.09913500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     82,    164,0.01421807,0.00984100,0.00984100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     82,    164,0.03728909,0.05013500,0.05013500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     82,    164,0.05745765,0.10059000,0.10059000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    148,    164,0.01430838,0.01028000,0.01028000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    148,    164,0.03589939,0.05013000,0.05013000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    148,    164,0.05437349,0.09931000,0.09931000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    164,    164,0.01397550,0.01011300,0.01011300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    164,    164,0.03552998,0.05006500,0.05006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    164,    164,0.05486470,0.09983000,0.09983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     82,    165,0.01421807,0.01004100,0.01004100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     82,    165,0.03707722,0.04982500,0.04982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     82,    165,0.05745765,0.10066500,0.10066500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    148,    165,0.01398319,0.01015000,0.01015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    148,    165,0.03549144,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    148,    165,0.05437349,0.10061000,0.10061000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    165,    165,0.01397550,0.01009300,0.01009300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    165,    165,0.03552998,0.04981000,0.04981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    165,    165,0.05486470,0.09968000,0.09968000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     83,    166,0.01421807,0.00985100,0.00985100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     83,    166,0.03623456,0.05010000,0.05010000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     83,    166,0.05680472,0.09958000,0.09958000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    149,    166,0.01366539,0.00990500,0.00990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    149,    166,0.03549144,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    149,    166,0.05437349,0.09992000,0.09992000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    166,    166,0.01397550,0.00998500,0.00998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    166,    166,0.03575205,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    166,    166,0.05486470,0.10036500,0.10036500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     84,    167,0.01421807,0.01005500,0.01005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     84,    167,0.03634779,0.05012500,0.05012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     84,    167,0.05615921,0.10023500,0.10023500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    150,    167,0.01366539,0.01004400,0.01004400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    150,    167,0.03546317,0.04967000,0.05056000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    150,    167,0.05437349,0.09995500,0.09995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    167,    167,0.01365788,0.01005100,0.01005100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    167,    167,0.03597550,0.04995000,0.04995000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    167,    167,0.05486470,0.10012500,0.10012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     84,    168,0.01421807,0.01012100,0.01012100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     84,    168,0.03646138,0.04996500,0.04996500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     84,    168,0.05686120,0.10018000,0.10018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    151,    168,0.01366539,0.00983200,0.00983200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    151,    168,0.03568481,0.04997000,0.04997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    151,    168,0.05437349,0.09998000,0.09998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    168,    168,0.01365788,0.01008100,0.01008100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    168,    168,0.03536228,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    168,    168,0.05361777,0.09920500,0.09920500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     84,    169,0.01421807,0.01012600,0.01012600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     84,    169,0.03563271,0.05011000,0.05011000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     84,    169,0.05621505,0.10073500,0.10073500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    152,    169,0.01366539,0.00987400,0.00987400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    152,    169,0.03568481,0.05018500,0.05018500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    152,    169,0.05437349,0.10020500,0.10020500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    169,    169,0.01365788,0.01018200,0.01018200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    169,    169,0.03580431,0.04997000,0.04997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    169,    169,0.05495822,0.10048000,0.10048000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     85,    170,0.01421807,0.01016000,0.01016000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     85,    170,0.03657920,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     85,    170,0.05691774,0.09975500,0.09975500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    153,    170,0.01366539,0.00993500,0.00993500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    153,    170,0.03568481,0.04990000,0.04990000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    153,    170,0.05437349,0.10036500,0.10036500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    170,    170,0.01365788,0.01000500,0.01000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    170,    170,0.03555001,0.05000500,0.05000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    170,    170,0.05433369,0.10049500,0.10049500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     86,    171,0.01421807,0.01013800,0.01013800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     86,    171,0.03647529,0.05018500,0.05018500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     86,    171,0.05691774,0.10058500,0.10058500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    154,    171,0.01366539,0.00980700,0.00980700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    154,    171,0.03568481,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    154,    171,0.05437349,0.09989500,0.09989500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    171,    171,0.01365788,0.00999900,0.00999900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    171,    171,0.03566111,0.04988500,0.04988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    171,    171,0.05450348,0.10015000,0.10015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     86,    172,0.01421807,0.01014500,0.01014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     86,    172,0.03606079,0.05013500,0.05013500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     86,    172,0.05497737,0.10012000,0.10012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    155,    172,0.01366539,0.01013600,0.01013600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    155,    172,0.03543137,0.05005000,0.05005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    155,    172,0.05437349,0.10011000,0.10011000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    172,    172,0.01365788,0.01013000,0.01013000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    172,    172,0.03566111,0.04990500,0.04990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    172,    172,0.05450348,0.10010000,0.10010000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     86,    173,0.01421807,0.01028100,0.01028100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     86,    173,0.03585590,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     86,    173,0.05609409,0.09960500,0.09960500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    156,    173,0.01366539,0.01007200,0.01007200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    156,    173,0.03565281,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    156,    173,0.05406455,0.09927500,0.09927500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    173,    173,0.01365788,0.01021800,0.01021800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    173,    173,0.03525587,0.04999500,0.04999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    173,    173,0.05326477,0.09986500,0.09986500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     87,    174,0.01357179,0.01003400,0.01003400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     87,    174,0.03483727,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     87,    174,0.05489891,0.09998000,0.09998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    157,    174,0.01366539,0.00992700,0.00992700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    157,    174,0.03568415,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    157,    174,0.05440245,0.09926000,0.09926000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    174,    174,0.01365788,0.01010600,0.01010600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    174,    174,0.03564148,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    174,    174,0.05492929,0.10021500,0.10021500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     88,    175,0.01357179,0.00979400,0.00979400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     88,    175,0.03570820,0.05018500,0.05018500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     88,    175,0.05489891,0.09936500,0.09936500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    158,    175,0.01366539,0.01006900,0.01006900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    158,    175,0.03544338,0.05005000,0.05005000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    158,    175,0.05440245,0.10019500,0.10019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    175,    175,0.01334747,0.00968300,0.00968300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    175,    175,0.03483145,0.04998000,0.04998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    175,    175,0.05243251,0.09978000,0.09978000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     88,    176,0.01357179,0.00992500,0.00992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     88,    176,0.03565748,0.04997000,0.04997000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     88,    176,0.05558514,0.10029500,0.10029500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    158,    176,0.01366539,0.01022100,0.01022100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    158,    176,0.03524200,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    158,    176,0.05378424,0.10012000,0.10012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    176,    176,0.01368116,0.01023000,0.01023000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    176,    176,0.03526684,0.04990500,0.04990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    176,    176,0.05374332,0.10025000,0.10025000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     88,    177,0.01357179,0.00991300,0.00991300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     88,    177,0.03515098,0.04981000,0.04981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     88,    177,0.05432184,0.10020500,0.10020500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    159,    177,0.01366539,0.01022900,0.01022900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    159,    177,0.03484152,0.05016500,0.05016500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    159,    177,0.05317305,0.09939500,0.09939500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    177,    177,0.01337022,0.00981600,0.00981600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    177,    177,0.03496627,0.05011000,0.05011000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    177,    177,0.05252188,0.09996500,0.09996500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     89,    178,0.01357179,0.01001600,0.01001600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     89,    178,0.03515098,0.04990500,0.04990500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     89,    178,0.05500087,0.09994500,0.09994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    160,    178,0.01366539,0.01002400,0.01002400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    160,    178,0.03505928,0.04984500,0.04984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    160,    178,0.05383772,0.10039500,0.10039500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    178,    178,0.01337022,0.00980000,0.00980000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    178,    178,0.03518481,0.05018500,0.05018500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    178,    178,0.05252188,0.09948000,0.09948000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     90,    179,0.01357179,0.01009700,0.01009700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     90,    179,0.03495126,0.04996000,0.04996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     90,    179,0.05500087,0.10058000,0.10058000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    161,    179,0.01366539,0.01001000,0.01001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    161,    179,0.03527840,0.04988500,0.04988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    161,    179,0.05383772,0.10005500,0.10005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    179,    179,0.01341880,0.00995800,0.00995800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    179,    179,0.03508485,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    179,    179,0.05222346,0.09959000,0.09959000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     90,    180,0.01357179,0.00991400,0.00991400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     90,    180,0.03516970,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     90,    180,0.05500087,0.09947000,0.09947000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    162,    180,0.01366539,0.00995500,0.00995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    162,    180,0.03487751,0.04993000,0.04993000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    162,    180,0.05322593,0.10020000,0.10020000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    180,    180,0.01331000,0.00982800,0.00982800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    180,    180,0.03513967,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    180,    180,0.05287625,0.10043000,0.10043000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     90,    181,0.01326334,0.00991700,0.00991700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     90,    181,0.03516970,0.04992500,0.04992500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     90,    181,0.05500087,0.10069500,0.10069500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    163,    181,0.01366539,0.01009000,0.01009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    163,    181,0.03509549,0.05008500,0.05008500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    163,    181,0.05322593,0.09978000,0.09978000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    181,    181,0.01364275,0.00997200,0.00997200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    181,    181,0.03557892,0.05015500,0.05015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    181,    181,0.05287625,0.09985500,0.09985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     91,    182,0.01392651,0.01014500,0.01014500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     91,    182,0.03538951,0.04995500,0.04995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     91,    182,0.05534462,0.09965500,0.09965500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    164,    182,0.01366539,0.01021100,0.01021100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    164,    182,0.03489609,0.04987500,0.04987500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    164,    182,0.05292351,0.09955000,0.09955000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    182,    182,0.01364275,0.01004500,0.01004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    182,    182,0.03537676,0.05017000,0.05017000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    182,    182,0.05287625,0.10031500,0.10031500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     92,    183,0.01345174,0.01001400,0.01001400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     92,    183,0.03518844,0.04990000,0.04990000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     92,    183,0.05503016,0.09986000,0.09986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    165,    183,0.01366539,0.01012500,0.01012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    165,    183,0.03533229,0.05003000,0.05003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    165,    183,0.05325428,0.10057000,0.10057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    183,    183,0.01364275,0.01017300,0.01017300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    183,    183,0.03497476,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    183,    183,0.05257582,0.10015500,0.10015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     92,    184,0.01345174,0.00991400,0.00991400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     92,    184,0.03463862,0.04996000,0.04996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     92,    184,0.05409215,0.10038500,0.10038500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    166,    184,0.01304423,0.01007200,0.01007200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    166,    184,0.03462966,0.04999500,0.04999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    166,    184,0.05325428,0.10040500,0.10040500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    184,    184,0.01364275,0.01009900,0.01009900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    184,    184,0.03457732,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    184,    184,0.05257582,0.09997500,0.09997500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     92,    185,0.01345174,0.00978400,0.00978400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     92,    185,0.03485511,0.05014000,0.05014000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     92,    185,0.05451475,0.10041500,0.10041500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    166,    185,0.01304423,0.00967000,0.00967000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    166,    185,0.03443290,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    166,    185,0.05325428,0.10019000,0.10019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    185,    185,0.01364275,0.01016500,0.01016500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    185,    185,0.03500953,0.04996000,0.04996000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    185,    185,0.05257582,0.10052000,0.10052000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     93,    186,0.01345174,0.01023200,0.01023200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     93,    186,0.03485511,0.04985500,0.04985500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     93,    186,0.05451475,0.10083500,0.10083500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    167,    186,0.01304423,0.00974500,0.00974500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    167,    186,0.03486331,0.05015000,0.05015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    167,    186,0.05264912,0.09928500,0.09928500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    186,    186,0.01364275,0.01025000,0.01025000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    186,    186,0.03461170,0.04999500,0.04999500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    186,    186,0.05257582,0.10055500,0.10055500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     94,    187,0.01345174,0.00988500,0.00988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     94,    187,0.03468182,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     94,    187,0.05451475,0.09991500,0.09991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    168,    187,0.01304423,0.00975900,0.00975900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    168,    187,0.03503354,0.05008000,0.05008000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    168,    187,0.05297817,0.09994500,0.09994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    187,    187,0.01364275,0.01012800,0.01012800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    187,    187,0.03504434,0.05000500,0.05000500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    187,    187,0.05257582,0.09931500,0.09931500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     94,    188,0.01345174,0.01003600,0.01003600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     94,    188,0.03468182,0.05001500,0.05001500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     94,    188,0.05420500,0.10030500,0.10030500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    169,    188,0.01304423,0.00968000,0.00968000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    169,    188,0.03423733,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    169,    188,0.05282767,0.10021000,0.10021000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    188,    188,0.01333269,0.00994800,0.00994800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    188,    188,0.03424788,0.05012500,0.05012500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    188,    188,0.05257582,0.09963500,0.09963500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     94,    189,0.01345174,0.01008400,0.01008400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     94,    189,0.03428771,0.04985000,0.04985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     94,    189,0.05437439,0.09958500,0.09958500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    170,    189,0.01304423,0.00987300,0.00987300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    170,    189,0.03509326,0.04998000,0.04998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    170,    189,0.05299275,0.09928500,0.09928500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    189,    189,0.01333269,0.00999400,0.00999400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    189,    189,0.03435490,0.05017500,0.05017500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    189,    189,0.05227709,0.09932000,0.09932000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     95,    190,0.01345174,0.00993200,0.00993200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     95,    190,0.03450201,0.05018000,0.05018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     95,    190,0.05406545,0.09953000,0.09953000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    171,    190,0.01337034,0.01013300,0.01013300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    171,    190,0.03449508,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    171,    190,0.05299275,0.10040500,0.10040500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    190,    190,0.01333269,0.01012900,0.01012900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    190,    190,0.03425731,0.04983000,0.04983000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    190,    190,0.05244947,0.09895500,0.10092000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     96,    191,0.01345174,0.01005200,0.01005200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     96,    191,0.03450201,0.05015000,0.05015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     96,    191,0.05440336,0.10002500,0.10002500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    172,    191,0.01337034,0.01026100,0.01026100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    172,    191,0.03420109,0.04991500,0.04991500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    172,    191,0.05284221,0.09974500,0.09974500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    191,    191,0.01341880,0.01030000,0.01030000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    191,    191,0.03417546,0.04870500,0.05030500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    191,    191,0.05244947,0.09936000,0.09936000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     96,    192,0.01345174,0.01010700,0.01010700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     96,    192,0.03410994,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     96,    192,0.05409425,0.09950500,0.09950500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    173,    192,0.01337034,0.01007600,0.01007600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    173,    192,0.03400676,0.05004500,0.05004500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    173,    192,0.05284221,0.09914500,0.09914500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    192,    192,0.01341880,0.01022300,0.01022300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    192,    192,0.03460265,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    192,    192,0.05261337,0.10079500,0.10079500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     96,    193,0.01345174,0.01011500,0.01011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     96,    193,0.03410994,0.04991000,0.04991000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     96,    193,0.05409425,0.09946500,0.09946500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    174,    193,0.01337034,0.01024800,0.01024800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    174,    193,0.03443185,0.05007000,0.05007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    174,    193,0.05317247,0.10053500,0.10053500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    193,    193,0.01341880,0.01015600,0.01015600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    193,    193,0.03440604,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    193,    193,0.05246390,0.10019500,0.10019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     97,    194,0.01345174,0.00987800,0.00987800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     97,    194,0.03426983,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     97,    194,0.05409425,0.10079500,0.10079500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    175,    194,0.01337034,0.01021700,0.01021700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    175,    194,0.03413839,0.05012000,0.05012000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    175,    194,0.05287035,0.09982500,0.09982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    194,    194,0.01341880,0.01015000,0.01015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    194,    194,0.03483612,0.05004000,0.05004000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    194,    194,0.05254588,0.10081000,0.10081000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     98,    195,0.01345174,0.00995800,0.00995800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     98,    195,0.03469821,0.05019000,0.05019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     98,    195,0.05409425,0.09936500,0.09936500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    176,    195,0.01337034,0.01028500,0.01028500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    176,    195,0.03435176,0.04998000,0.04998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    176,    195,0.05320079,0.09975000,0.09975000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    195,    195,0.01341880,0.01022500,0.01022500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    195,    195,0.03479282,0.04994500,0.04994500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    195,    195,0.05271008,0.10053000,0.10053000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     98,    196,0.01345174,0.01006500,0.01006500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     98,    196,0.03420533,0.04982500,0.04982500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     98,    196,0.05401190,0.09877500,0.10108000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    176,    196,0.01337034,0.01030700,0.01030700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    176,    196,0.03357104,0.04981500,0.04981500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    176,    196,0.05259624,0.09930500,0.09930500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    196,    196,0.01341880,0.01027900,0.01027900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    196,    196,0.03424606,0.04897000,0.05069500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    196,    196,0.05246675,0.10087500,0.10087500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     98,    197,0.01345174,0.01017200,0.01017200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     98,    197,0.03381664,0.04993500,0.04993500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     98,    197,0.05401190,0.10065000,0.10065000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    177,    197,0.01337034,0.01012400,0.01012400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    177,    197,0.03420049,0.05003000,0.05003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    177,    197,0.05292496,0.10051500,0.10051500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    197,    197,0.01280886,0.00970200,0.00970200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    197,    197,0.03425975,0.04895000,0.05050000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    197,    197,0.05254873,0.09984500,0.09984500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     99,    198,0.01345174,0.01015000,0.01015000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     99,    198,0.03429218,0.04995500,0.04995500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     99,    198,0.05405338,0.09886500,0.10131000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    178,    198,0.01337034,0.01022300,0.01022300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    178,    198,0.03420049,0.05016000,0.05016000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    178,    198,0.05292496,0.09981000,0.09981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    198,    198,0.01280886,0.00969300,0.00969300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    198,    198,0.03468800,0.05018000,0.05018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    198,    198,0.05254873,0.09931000,0.09931000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    100,    199,0.01314602,0.00973900,0.00973900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    100,    199,0.03429218,0.05018000,0.05018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    100,    199,0.05405338,0.10003000,0.10003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    179,    199,0.01306647,0.01007600,0.01007600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    179,    199,0.03381185,0.05008000,0.05008000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    179,    199,0.05262425,0.09913500,0.09913500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    199,    199,0.01280886,0.00995300,0.00995300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    199,    199,0.03389964,0.05003500,0.05003500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    199,    199,0.05225015,0.09954000,0.09954000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     20,    200,0.01060761,0.00969400,0.00969400)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     20,    200,0.03214068,0.05002000,0.05002000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     20,    200,0.05260161,0.09978000,0.09978000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    100,    200,0.01314602,0.00968200,0.00968200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    100,    200,0.03409734,0.05013000,0.05013000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    100,    200,0.05405338,0.09934000,0.09934000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    180,    200,0.01306647,0.00998500,0.00998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    180,    200,0.03381185,0.04997500,0.04997500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    180,    200,0.05295316,0.10082000,0.10082000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    200,    200,0.01280886,0.00972300,0.00972300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    200,    200,0.03389964,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    200,    200,0.05249508,0.09924500,0.09924500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     30,    300,0.00876662,0.00982300,0.00982300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     30,    300,0.02672856,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     30,    300,0.04428751,0.10047500,0.10047500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    150,    300,0.03139568,0.04984000,0.04984000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    150,    300,0.04891587,0.10056000,0.10056000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    300,    300,0.01169824,0.00975000,0.01012600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    300,    300,0.03081785,0.05038800,0.05038800)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    300,    300,0.04891587,0.10087100,0.10087100)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     40,    400,0.00760740,0.01005200,0.01005200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     40,    400,0.02374645,0.05001500,0.05001500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     40,    400,0.04003262,0.09985000,0.09985000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    200,    400,0.02925507,0.05017500,0.05017500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    200,    400,0.04558070,0.10046500,0.10046500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    400,    400,0.01116650,0.01016700,0.01016700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    400,    400,0.02882302,0.04937500,0.05019500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    400,    400,0.04446897,0.09993000,0.09993000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     25,    500,0.00625997,0.00998000,0.01001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     25,    500,0.02131257,0.04989000,0.04989000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     25,    500,0.03562142,0.10003500,0.10003500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     50,    500,0.00691582,0.00987200,0.00987200)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     50,    500,0.02146502,0.05009500,0.05009500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     50,    500,0.03684820,0.10057000,0.10057000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    250,    500,0.02759285,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    250,    500,0.04350885,0.09996500,0.09996500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    500,    500,0.01073585,0.01002700,0.01002700)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    500,    500,0.02767665,0.05001500,0.05001500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    500,    500,0.04244766,0.10003000,0.10003000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     60,    600,0.00636311,0.01005500,0.01005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     60,    600,0.02036738,0.04987000,0.04987000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     60,    600,0.03412646,0.09929000,0.09929000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    300,    600,0.02649541,0.05007500,0.05007500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    300,    600,0.04153117,0.10052500,0.10052500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    600,    600,0.01024786,0.01014161,0.01014161)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    600,    600,0.02657587,0.05013000,0.05013000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    600,    600,0.04100058,0.10025500,0.10025500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     70,    700,0.00607388,0.01009600,0.01009600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     70,    700,0.01967304,0.05019000,0.05019000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     70,    700,0.03276916,0.09921000,0.09921000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    350,    700,0.02574270,0.05007000,0.05007000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    350,    700,0.04011534,0.10009000,0.10009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    700,    700,0.00978204,0.00988790,0.00988790)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    700,    700,0.02582088,0.05011500,0.05011500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    700,    700,0.04006875,0.09977000,0.09977000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     80,    800,0.00579779,0.01023500,0.01023500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     80,    800,0.01855525,0.04998000,0.04998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     80,    800,0.03053490,0.09956500,0.09956500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    400,    800,0.02537703,0.04998000,0.04998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    400,    800,0.03874777,0.09916500,0.09916500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    800,    800,0.00978204,0.01023900,0.01023900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    800,    800,0.02552746,0.04981000,0.04981000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    800,    800,0.03870277,0.09912000,0.09912000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,     90,    900,0.00550000,0.00997300,0.00997300)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,     90,    900,0.01781726,0.05001000,0.05001000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,     90,    900,0.02984092,0.09937000,0.09937000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    450,    900,0.02472819,0.04998500,0.04998500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    450,    900,0.03830745,0.10018000,0.10018000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    900,    900,0.00933741,0.00996257,0.00996257)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    900,    900,0.02501981,0.04992000,0.04992000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    900,    900,0.03870277,0.10050500,0.10050500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    100,   1000,0.00547000,0.01009184,0.01009184)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    100,   1000,0.01717458,0.04983500,0.04983500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    100,   1000,0.02918160,0.10066500,0.10066500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    500,   1000,0.02423643,0.05009000,0.05009000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    500,   1000,0.03743683,0.10015500,0.10015500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,   1000,   1000,0.00912519,0.00990900,0.00990900)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,   1000,   1000,0.02473549,0.05006000,0.05006000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,   1000,   1000,0.03826296,0.09952500,0.09952500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    200,   2000,0.00440000,0.01036707,0.01036707)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    200,   2000,0.01403257,0.05003500,0.05003500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    200,   2000,0.02411703,0.10043500,0.10043500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,   1000,   2000,0.02140718,0.04988500,0.04988500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,   1000,   2000,0.03403348,0.10064500,0.10064500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,   2000,   2000,0.00829563,0.01009600,0.01009600)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,   2000,   2000,0.02185870,0.04980500,0.05031000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,   2000,   2000,0.03400226,0.09998000,0.09998000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,    300,   3000,0.00400000,0.01041389,0.01041389)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,    300,   3000,0.01279675,0.04994000,0.04994000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,    300,   3000,0.02192457,0.09999000,0.09999000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,   1500,   3000,0.02027378,0.05005500,0.05005500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,   1500,   3000,0.03189688,0.09972500,0.09972500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,   3000,   3000,0.00791855,0.01022833,0.01022833)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,   3000,   3000,0.02098932,0.05008847,0.05008847)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,   3000,   3000,0.03226351,0.10045685,0.10045685)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,   1000,  10000,0.00290000,0.00933916,0.00933916)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,   1000,  10000,0.01000000,0.04992051,0.04992051)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,   1000,  10000,0.01700000,0.09767121,0.09767121)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,  10000,  10000,0.00688678,0.01003500,0.01003500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,  10000,  10000,0.01802196,0.04940500,0.04940500)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,  10000,  10000,0.02804982,0.09986000,0.09986000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,  10000, 100000,0.00210000,0.00995965,0.00995965)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,  10000, 100000,0.00770000,0.05511307,0.05511307)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,  10000, 100000,0.01310000,0.10749124,0.10749124)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010,  50000, 100000,0.00535272,0.01101478,0.01101478)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050,  50000, 100000,0.01350000,0.04897902,0.04897902)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100,  50000, 100000,0.02200000,0.10181296,0.10181296)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.010, 100000, 100000,0.00535272,0.00932000,0.00932000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.050, 100000, 100000,0.01498281,0.05132000,0.05132000)
GoldmanKaplan2sLookup =GoldmanKaplan2sLookup \ (0.100, 100000, 100000,0.02295306,0.09943200,0.09943200)

end

*EOF